@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -24,18 +24,12 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include "Array.h"
+#include "Array-flags.h"
 
 // These have to be defined somewhere, but only once.
 
-#if defined (HEAVYWEIGHT_INDEXING)
-
-int liboctave_dfi_flag = 0;
-int liboctave_pcv_flag = 0;
-int liboctave_pzo_flag = 0;
-int liboctave_rre_flag = 0;
-
-#endif
+bool liboctave_wfi_flag = false;
+bool liboctave_wrore_flag = false;
 
 /*
 ;;; Local Variables: ***
