@@ -71,52 +71,51 @@ Array<T>::squeeze (void) const
 {
   Array<T> retval = *this;
 
-  bool dims_changed = false;
-
-  dim_vector new_dimensions = dimensions;
-
-  int k = 0;
-
-  for (int i = 0; i < ndims (); i++)
+  if (ndims () > 2)
     {
-      if (dimensions(i) == 1)
-	dims_changed = true;
-      else
-	new_dimensions(k++) = dimensions(i);
-    }
+      bool dims_changed = false;
 
-  if (dims_changed)
-    {
-      switch (k)
+      dim_vector new_dimensions = dimensions;
+
+      int k = 0;
+
+      for (int i = 0; i < ndims (); i++)
 	{
-	case 0:
-	  new_dimensions = dim_vector (1, 1);
-	  break;
+	  if (dimensions(i) == 1)
+	    dims_changed = true;
+	  else
+	    new_dimensions(k++) = dimensions(i);
+	}
 
-	case 1:
-	  {
-	    int tmp = new_dimensions(0);
+      if (dims_changed)
+	{
+	  switch (k)
+	    {
+	    case 0:
+	      new_dimensions = dim_vector (1, 1);
+	      break;
 
-	    new_dimensions.resize (2);
-
-	    if (dimensions(0) == 1)
-	      {
-		new_dimensions(0) = 1;
-		new_dimensions(1) = tmp;
-	      }
-	    else
+	    case 1:
 	      {
+		int tmp = new_dimensions(0);
+
+		new_dimensions.resize (2);
+
 		new_dimensions(0) = tmp;
 		new_dimensions(1) = 1;
 	      }
-	  }
-	  break;
+	      break;
 
-	default:
-	  new_dimensions.resize (k);
-	  break;
+	    default:
+	      new_dimensions.resize (k);
+	      break;
+	    }
 	}
 
+      // XXX FIXME XXX -- it would be better if we did not have to do
+      // this, so we could share the data while still having different
+      // dimension vectors.
+
       retval.make_unique ();
 
       retval.dimensions = new_dimensions;
@@ -420,6 +419,8 @@ Array<T>::reshape (const dim_vector& new_dims) const
       else
 	(*current_liboctave_error_handler) ("reshape: size mismatch");
     }
+  else
+    retval = *this;
 
   return retval;
 }
@@ -560,8 +561,6 @@ Array<T>::resize_no_fill (const dim_vector& dv)
   if (same_size)
     return;
 
-  int old_len = length ();
-
   typename Array<T>::ArrayRep *old_rep = rep;
   const T *old_data = data ();
 
@@ -569,16 +568,27 @@ Array<T>::resize_no_fill (const dim_vector& dv)
 
   rep = new typename Array<T>::ArrayRep (ts);
 
+  dim_vector dv_old = dimensions;
+  int dv_old_orig_len = dv_old.length ();
   dimensions = dv;
+  int ts_old = get_size (dv_old);
 
-  if (ts > 0)
+  if (ts > 0 && ts_old > 0 && dv_old_orig_len > 0)
     {
       Array<int> ra_idx (dimensions.length (), 0);
 
-      for (int i = 0; i < old_len; i++)
+      if (n > dv_old_orig_len)
 	{
-	  if (index_in_bounds (ra_idx, dimensions))
-	    xelem (ra_idx) = old_data[i];
+	  dv_old.resize (n);
+
+	  for (int i = dv_old_orig_len; i < n; i++)
+	    dv_old.elem (i) = 1;
+	}
+
+      for (int i = 0; i < ts; i++)
+	{
+	  if (index_in_bounds (ra_idx, dv_old))
+	    rep->elem (i) = old_data[get_scalar_idx (ra_idx, dv_old)];
 
 	  increment_index (ra_idx, dimensions);
 	}
@@ -894,47 +904,39 @@ Array<T>::resize_and_fill (const dim_vector& dv, const T& val)
   typename Array<T>::ArrayRep *old_rep = rep;
   const T *old_data = data ();
 
-  int old_len = length ();
-
   int len = get_size (dv);
 
   rep = new typename Array<T>::ArrayRep (len);
 
   dim_vector dv_old = dimensions;
-
   int dv_old_orig_len = dv_old.length ();
-
-  if (n > dv_old_orig_len)
-    {
-      dv_old.resize (n);
-
-      for (int i = dv_old_orig_len; i < n; i++)
-	dv_old.elem (i) = 1;
-    }
-
   dimensions = dv;
 
-  if (len > 0)
+  if (len > 0 && dv_old_orig_len > 0)
     {
       Array<int> ra_idx (dimensions.length (), 0);
+      
+      if (n > dv_old_orig_len)
+	{
+	  dv_old.resize (n);
 
-      // XXX FIXME XXX -- it is much simpler to fill the whole array
-      // first, but probably slower for large arrays, or if the assignment
-      // operator for the type T is expensive.  OTOH, the logic for
-      // deciding whether an element needs the copied value or the filled
-      // value might be more expensive.
+	  for (int i = dv_old_orig_len; i < n; i++)
+	    dv_old.elem (i) = 1;
+	}
 
       for (int i = 0; i < len; i++)
-	rep->elem (i) = val;
-
-      for (int i = 0; i < old_len; i++)
 	{
 	  if (index_in_bounds (ra_idx, dv_old))
-	    xelem (ra_idx) = old_data[get_scalar_idx (ra_idx, dv_old)];
-
-	  increment_index (ra_idx, dv_old);
+	    rep->elem (i) = old_data[get_scalar_idx (ra_idx, dv_old)];
+	  else
+	    rep->elem (i) = val;
+	  
+	  increment_index (ra_idx, dimensions);
 	}
     }
+  else
+    for (int i = 0; i < len; i++)
+      rep->elem (i) = val;
 
   if (--old_rep->count <= 0)
     delete old_rep;
@@ -1040,11 +1042,14 @@ Array<T>::insert (const Array<T>& a, const Array<int>& ra_idx)
 
   if (n == dimensions.length ())
     {
-      dim_vector a_dims = a.dims ();
+      dim_vector dva = a.dims ();
+      dim_vector dv = dims ();
+      int len_a = dva.length ();
 
       for (int i = 0; i < n; i++)
 	{
-	  if (ra_idx(i) < 0 || ra_idx(i) + a_dims(i) > dimensions(i))
+	  if (ra_idx(i) < 0 || (ra_idx(i) + 
+				(i < len_a ? dva(i) : 1)) > dimensions(i))
 	    {
 	      (*current_liboctave_error_handler)
 		("Array<T>::insert: range error for insert");
@@ -1052,15 +1057,39 @@ Array<T>::insert (const Array<T>& a, const Array<int>& ra_idx)
 	    }
 	}
 
+      if (dva.numel ())
+        {
+	  const T *a_data = a.data ();   
+	  int numel_to_move = dva (0);
+	  int skip = dv (0);
+	  for (int i = 0; i < len_a - 1; i++)
+	    if (ra_idx(i) == 0 && dva(i) == dv(i))
+	      {
+		numel_to_move *= dva(i+1);
+		skip *= dv(i+1);
+	      }
+	    else
+	      {
+		skip -= dva(i);
+		break;
+	      }
 
-#if 0
-      // XXX FIXME XXX -- need to copy elements
-
-      for (int j = 0; j < a_cols; j++)
-	for (int i = 0; i < a_rows; i++)
-	  elem (r+i, c+j) = a.elem (i, j);
-#endif
+	  int jidx = ra_idx (n - 1);
+	  for (int i = n-2; i >= 0; i--)
+	    {
+	      jidx *= dv (i);
+	      jidx += ra_idx (i);
+	    }
 
+	  int iidx = 0;
+	  int moves = dva.numel () / numel_to_move;
+	  for (int i = 0; i < moves; i++)
+	    {
+	      for (int j = 0; j < numel_to_move; j++)
+		elem (jidx++) = a_data[iidx++];
+	      jidx += skip;
+	    }
+	}
     }
   else
     (*current_liboctave_error_handler)
@@ -1905,19 +1934,27 @@ Array<T>::index (idx_vector& idx_arg, int resize_ok, const T& rfv) const
 {
   Array<T> retval;
 
-  switch (ndims ())
+  dim_vector dv = idx_arg.orig_dimensions ();
+
+  if (dv.length () > 2 || ndims () > 2)
+    retval = indexN (idx_arg, resize_ok, rfv);
+  else
     {
-    case 1:
-      retval = index1 (idx_arg, resize_ok, rfv);
-      break;
+      switch (ndims ())
+	{
+	case 1:
+	  retval = index1 (idx_arg, resize_ok, rfv);
+	  break;
 
-    case 2:
-      retval = index2 (idx_arg, resize_ok, rfv);
-      break;
+	case 2:
+	  retval = index2 (idx_arg, resize_ok, rfv);
+	  break;
 
-    default:
-      retval = indexN (idx_arg, resize_ok, rfv);
-      break;
+	default:
+	  (*current_liboctave_error_handler)
+	    ("invalid array (internal error)");
+	  break;
+	}
     }
 
   return retval;
@@ -2004,7 +2041,7 @@ Array<T>::index2 (idx_vector& idx_arg, int resize_ok, const T& rfv) const
 
       if (len == 0 && idx_arg.one_zero_only ())
 	retval = Array<T> (tmp, dim_vector (0, 0));
-      else
+      else if (len >= idx_orig_dims.numel ())
 	retval = Array<T> (tmp, idx_orig_dims);
     }
   else if (nr == 1 || nc == 1)
@@ -2025,7 +2062,7 @@ Array<T>::index2 (idx_vector& idx_arg, int resize_ok, const T& rfv) const
 	  else
 	    retval = Array<T> (tmp, dim_vector (len, 1));
 	}
-      else
+      else if (len >= idx_orig_dims.numel ())
 	retval = Array<T> (tmp, idx_orig_dims);
     }
   else
@@ -2101,8 +2138,13 @@ Array<T>::indexN (idx_vector& ra_idx, int resize_ok, const T& rfv) const
 
       Array<T> tmp = Array<T>::index (ra_idx, resize_ok);
 
-      if (tmp.length () != 0)
-	retval = Array<T> (tmp, idx_orig_dims);
+      int len = tmp.length ();
+
+      if (len != 0)
+	{
+	  if (len >= idx_orig_dims.numel ())
+	    retval = Array<T> (tmp, idx_orig_dims);
+	}
       else
 	retval = Array<T> (tmp, dim_vector (0, 0));
     }
@@ -2154,7 +2196,7 @@ Array<T>::indexN (idx_vector& ra_idx, int resize_ok, const T& rfv) const
 
 	      retval = Array<T> (tmp, new_dims);
 	    }
-	  else
+	  else if (tmp.length () >= idx_orig_dims.numel ())
 	    retval = Array<T> (tmp, idx_orig_dims);
 
 	  (*current_liboctave_error_handler)
@@ -2281,78 +2323,82 @@ Array<T>::index (Array<idx_vector>& ra_idx, int resize_ok, const T&) const
 
   int ra_idx_len = ra_idx.length ();
 
-  while (ra_idx_len > n_dims)
+  bool trim_trailing_singletons = true;
+  for (int j = ra_idx_len; j > n_dims; j--)
     {
-      if (ra_idx(ra_idx_len-1) == 1)
+      idx_vector iidx = ra_idx (ra_idx_len-1);
+      if (iidx.capacity () == 1 && trim_trailing_singletons)
 	ra_idx_len--;
       else
-	break;
+	trim_trailing_singletons = false;
+
+      for (int i = 0; i < iidx.capacity (); i++)
+	if (iidx (i) != 0)
+	  {
+	    (*current_liboctave_error_handler)
+	      ("index exceeds N-d array dimensions");
+	    
+	    return retval;
+	  }
     }
 
   ra_idx.resize (ra_idx_len);
 
-  if (n_dims < ra_idx.length ())
-    {
-      (*current_liboctave_error_handler)
-	("index exceeds N-d array dimensions");
+  dim_vector new_dims = dims ();
+  dim_vector frozen_lengths;
 
-      return retval;
+  if (! any_orig_empty (ra_idx) && ra_idx_len < n_dims)
+    frozen_lengths = short_freeze (ra_idx, dimensions, resize_ok);
+  else
+    {
+      new_dims.resize (ra_idx_len, 1);
+      frozen_lengths = freeze (ra_idx, new_dims, resize_ok);
     }
 
-  dim_vector frozen_lengths = short_freeze (ra_idx, dimensions, resize_ok);
-
-  if (frozen_lengths.length () <= n_dims)
+  if (all_ok (ra_idx))
     {
-      if (all_ok (ra_idx))
+      if (any_orig_empty (ra_idx) || frozen_lengths.any_zero ())
 	{
-	  if (any_orig_empty (ra_idx) || frozen_lengths.any_zero ())
+	  frozen_lengths.chop_trailing_singletons ();
+
+	  retval.resize (frozen_lengths);
+	}
+      else if (frozen_lengths.length () == n_dims
+	       && all_colon_equiv (ra_idx, dimensions))
+	{
+	  retval = *this;
+	}
+      else
+	{
+	  dim_vector frozen_lengths_for_resize = frozen_lengths;
+
+	  frozen_lengths_for_resize.chop_trailing_singletons ();
+
+	  retval.resize (frozen_lengths_for_resize);
+
+	  int n = retval.length ();
+
+	  Array<int> result_idx (ra_idx.length (), 0);
+
+	  Array<int> elt_idx;
+
+	  for (int i = 0; i < n; i++)
 	    {
-	      frozen_lengths.chop_trailing_singletons ();
+	      elt_idx = get_elt_idx (ra_idx, result_idx);
 
-	      retval.resize (frozen_lengths);
-	    }
-	  else if (frozen_lengths.length () == n_dims
-		   && all_colon_equiv (ra_idx, dimensions))
-	    {
-	      retval = *this;
-	    }
-	  else
-	    {
-	      dim_vector frozen_lengths_for_resize = frozen_lengths;
+	      int numelem_elt = get_scalar_idx (elt_idx, new_dims);
 
-	      frozen_lengths_for_resize.chop_trailing_singletons ();
+	      if (numelem_elt > length () || numelem_elt < 0)
+		(*current_liboctave_error_handler)
+		  ("invalid N-d array index");
+	      else
+		retval.elem (i) = elem (numelem_elt);
 
-	      retval.resize (frozen_lengths_for_resize);
+	      increment_index (result_idx, frozen_lengths);
 
-	      int n = retval.length ();
-
-	      Array<int> result_idx (ra_idx.length (), 0);
-
-	      dim_vector this_dims = dims ();
-
-	      Array<int> elt_idx;
-
-	      for (int i = 0; i < n; i++)
-		{
-		  elt_idx = get_elt_idx (ra_idx, result_idx);
-
-		  int numelem_elt = get_scalar_idx (elt_idx, this_dims);
-
-		  if (numelem_elt > length () || numelem_elt < 0)
-		    (*current_liboctave_error_handler)
-		      ("invalid N-d array index");
-		  else
-		    retval.elem (i) = elem (numelem_elt);
-
-		  increment_index (result_idx, frozen_lengths);
-
-		}
 	    }
 	}
     }
-  else
-    (*current_liboctave_error_handler)
-      ("invalid number of dimensions for N-dimensional array index");
 
   return retval;
 }
@@ -2506,16 +2552,22 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
   int lhs_nr = lhs.rows ();
   int lhs_nc = lhs.cols ();
 
-  int rhs_nr = rhs.rows ();
-  int rhs_nc = rhs.cols ();
+  Array<RT> xrhs = rhs;
 
-  if (rhs.length () > 2)
+  int rhs_nr = xrhs.rows ();
+  int rhs_nc = xrhs.cols ();
+
+  if (xrhs.ndims () > 2)
     {
-      dim_vector dv_tmp = rhs.squeeze().dims ();
+      xrhs = xrhs.squeeze ();
+
+      dim_vector dv_tmp = xrhs.dims ();
 
       switch (dv_tmp.length ())
 	{
 	case 1:
+	  // XXX FIXME XXX -- this case should be unnecessary, because
+	  // squeeze should always return an object with 2 dimensions.
 	  if (rhs_nr == 1)
 	    rhs_nc = dv_tmp.elem (0);
 	  break;
@@ -2575,7 +2627,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		    {
 		      MAYBE_RESIZE_LHS;
 
-		      RT scalar = rhs.elem (0, 0);
+		      RT scalar = xrhs.elem (0, 0);
 
 		      for (int j = 0; j < m; j++)
 			{
@@ -2600,7 +2652,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 			  for (int i = 0; i < n; i++)
 			    {
 			      int ii = idx_i.elem (i);
-			      lhs.elem (ii, jj) = rhs.elem (i, j);
+			      lhs.elem (ii, jj) = xrhs.elem (i, j);
 			    }
 			}
 		    }
@@ -2608,7 +2660,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      else if (n == 0 && m == 0)
 		{
 		  if (! ((rhs_nr == 1 && rhs_nc == 1)
-			 || (rhs_nr == 0 && rhs_nc == 0)))
+			 || (rhs_nr == 0 || rhs_nc == 0)))
 		    {
 		      (*current_liboctave_error_handler)
 		("A([], []) = X: X must be an empty matrix or a scalar");
@@ -2670,7 +2722,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 			}
 		    }
 
-		  if (assign1 ((Array<LT>&) lhs, (Array<RT>&) rhs, rfv))
+		  if (assign1 (lhs, xrhs, rfv))
 		    {
 		      int len = lhs.length ();
 
@@ -2701,7 +2753,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		lhs.maybe_delete_elements (idx_i);
 	      else
 		{
-		  if (assign1 ((Array<LT>&) lhs, (Array<RT>&) rhs, rfv))
+		  if (assign1 (lhs, xrhs, rfv))
 		    lhs.dimensions = dim_vector (1, lhs.length ());
 		  else
 		    retval = 0;
@@ -2719,7 +2771,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		lhs.maybe_delete_elements (idx_i);
 	      else
 		{
-		  if (assign1 ((Array<LT>&) lhs, (Array<RT>&) rhs, rfv))
+		  if (assign1 (lhs, xrhs, rfv))
 		    lhs.dimensions = dim_vector (lhs.length (), 1);
 		  else
 		    retval = 0;
@@ -2746,7 +2798,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      else if (len == 0)
 		{
 		  if (! ((rhs_nr == 1 && rhs_nc == 1)
-			 || (rhs_nr == 0 && rhs_nc == 0)))
+			 || (rhs_nr == 0 || rhs_nc == 0)))
 		    (*current_liboctave_error_handler)
 		      ("A([]) = X: X must be an empty matrix or scalar");
 		}
@@ -2760,7 +2812,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 			  int ii = idx_i.elem (k++);
 			  int fr = ii % lhs_nr;
 			  int fc = (ii - fr) / lhs_nr;
-			  lhs.elem (fr, fc) = rhs.elem (i, j);
+			  lhs.elem (fr, fc) = xrhs.elem (i, j);
 			}
 		    }
 		}
@@ -2839,7 +2891,7 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	{
 	  if (len == 0)
 	    {
-	      if (! (rhs_dims.all_ones () || rhs_dims.all_zero ()))
+	      if (! (rhs_dims.all_ones () || rhs_dims.any_zero ()))
 		{
 		  (*current_liboctave_error_handler)
 		    ("A([]) = X: X must be an empty matrix or scalar");
@@ -2896,7 +2948,9 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 
       if (n_idx < lhs_dims_len)
 	{
-	  // Collapse dimensions beyond last index.
+	  // Collapse dimensions beyond last index.  Note that we
+	  // delay resizing LHS until we know that the assignment will
+	  // succeed.
 
 	  if (liboctave_wfi_flag && ! (idx(n_idx-1).is_colon ()))
 	    (*current_liboctave_warning_handler)
@@ -2907,10 +2961,6 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 
 	  lhs_dims.resize (n_idx);
 
-	  lhs.resize (lhs_dims);
-
-	  lhs_dims = lhs.dims ();
-
 	  lhs_dims_len = lhs_dims.length ();
 	}
 
@@ -2935,8 +2985,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      // We didn't start out with all zero dimensions, so if
 	      // index is a colon, it refers to the current LHS
 	      // dimension.  Otherwise, it is OK to enlarge to a
-	      // dimension given by the largest index (but that index
-	      // needs to be a number, not a colon).
+	      // dimension given by the largest index, but if that 
+	      // index is a colon the new dimension is singleton.
 
 	      if (i < lhs_dims_len
 		  && (idx(i).is_colon () || idx(i).max () < lhs_dims(i)))
@@ -2944,17 +2994,7 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      else if (! idx(i).is_colon ())
 		new_dims(i) = idx(i).max () + 1;
 	      else
-		{
-		  // XXX FIXME XXX -- can we provide a more
-		  // informative message here?
-
-		  (*current_liboctave_error_handler)
-		    ("invalid array index for assignment");
-
-		  retval = 0;
-
-		  break;
-		}
+		new_dims(i) = 1;
 	    }
 	}
 
@@ -2976,6 +3016,11 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	    }
 	  else
 	    {
+	      // Determine final dimensions for LHS and reset the
+	      // current size of the LHS.  Note that we delay actually
+	      // resizing LHS until we know that the assignment will
+	      // succeed.
+
 	      if (n_idx < orig_lhs_dims_len)
 		{
 		  for (int i = 0; i < n_idx-1; i++)
@@ -2984,9 +3029,7 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      else
 		final_lhs_dims = new_dims;
 
-	      lhs.resize_and_fill (new_dims, rfv);
-
-	      lhs_dims = lhs.dims ();
+	      lhs_dims = new_dims;
 
 	      lhs_dims_len = lhs_dims.length ();
 
@@ -2994,6 +3037,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 
 	      if (rhs_is_scalar)
 		{
+		  lhs.resize_and_fill (new_dims, rfv);
+
 		  if  (! final_lhs_dims.any_zero ())
 		    {
 		      int n = Array<LT>::get_size (frozen_len);
@@ -3051,6 +3096,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		    }
 		  else
 		    {
+		      lhs.resize_and_fill (new_dims, rfv);
+
 		      if  (! final_lhs_dims.any_zero ())
 			{
 			  int n = Array<LT>::get_size (frozen_len);
@@ -3071,39 +3118,18 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	    }
 	}
 
-      lhs.resize (final_lhs_dims);
+      if (retval != 0)
+	lhs.resize (final_lhs_dims);
     }
 
-  lhs.chop_trailing_singletons ();
+  if (retval != 0)
+    lhs.chop_trailing_singletons ();
 
   lhs.clear_index ();
 
   return retval;
 }
 
-template <class T>
-int
-cat_ra (Array<T>& ra, const Array<T>& ra_arg, int dim, int idx, int move)
-{
-  dim_vector dv_arg = ra_arg.dims (); 
-  
-  const T *arg_data = ra_arg.data ();
-  
-  int numel_to_move = dv_arg(0);
-
-  int numel_arg = dv_arg.length ();
-
-  int ii_limit = dim+1 > numel_arg ? numel_arg : dim + 1;
-  
-  for (int ii = 1; ii < ii_limit; ii++)
-    numel_to_move *= dv_arg(ii);
-
-  for (int j = 0; j < numel_to_move; j++)
-    ra.elem (idx++) = arg_data[numel_to_move * move + j];
-  
-  return idx;
-}
-
 template <class T>
 void
 Array<T>::print_info (std::ostream& os, const std::string& prefix) const
