@@ -133,13 +133,12 @@ protected:
 	rep->fill (val);
     }
 
-  typename Array<T>::ArrayRep *rep;
-
 public:
 
-  // !!! WARNING !!! -- this is public because template friends don't
-  // work properly with versions of gcc earlier than 3.3.  You should
-  // not access this data member directly!
+  // !!! WARNING !!! -- these should be protected, not public.  You
+  // should not access these data members directly!
+
+  typename Array<T>::ArrayRep *rep;
 
   dim_vector dimensions;
 
@@ -166,6 +165,18 @@ private:
       return nr;
     }
 
+  template <class U>
+  T *
+  coerce (const U *a, int len)
+  {
+    T *retval = new T [len];
+
+    for (int i = 0; i < len; i++)
+      retval[i] = T (a[i]);
+
+    return retval;
+  }
+
 public:
 
   Array (void)
@@ -183,6 +194,15 @@ public:
       fill (val);
     }
 
+  // Type conversion case.
+  template <class U>
+  Array (const Array<U>& a)
+    : rep (new typename Array<T>::ArrayRep (coerce (a.data (), a.length ()), a.length ())),
+      dimensions (a.dimensions), idx (0), idx_count (0)
+    {
+    }
+
+  // No type conversion case.
   Array (const Array<T>& a)
     : rep (a.rep), dimensions (a.dimensions), idx (0), idx_count (0)
     {
@@ -204,7 +224,7 @@ public:
 
   Array (const Array<T>& a, const dim_vector& dv);
 
-  ~Array (void);
+  virtual ~Array (void);
 
   Array<T>& operator = (const Array<T>& a)
     {
@@ -241,6 +261,8 @@ public:
   int columns (void) const { return dim2 (); }
   int pages (void) const { return dim3 (); }
 
+  size_t byte_size (void) const { return numel () * sizeof (T); }
+
   dim_vector dims (void) const { return dimensions; }
 
   Array<T> squeeze (void) const;
@@ -521,10 +543,6 @@ public:
 // Array<T>::dimensions should be protected, not public, but we can't
 // do that because of bugs in gcc prior to 3.3.
 
-template <class T>
-int 
-cat_ra (Array<T>& ra, const Array<T>& ra_arg, int dim, int idx, int move);
-
 template <class LT, class RT>
 /* friend */ int
 assign (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv);
@@ -560,10 +578,6 @@ assign (Array<LT>& lhs, const Array<RT>& rhs)
   template class Array<T>; \
   template T resize_fill_value (const T&); \
 
-#define INSTANTIATE_ARRAY_CAT(T) \
-  template int cat_ra (Array<T>& ra, const Array<T>& ra_arg, \
-                       int dim, int idx, int move)
-
 #define INSTANTIATE_ARRAY_AND_ASSIGN(T) \
   INSTANTIATE_ARRAY (T); \
   INSTANTIATE_ARRAY_ASSIGN (T, T)
