@@ -33,9 +33,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mx-defs.h"
 #include "mx-op-defs.h"
 
-#include "data-conv.h"
-#include "mach-info.h"
-
 class
 ComplexNDArray : public MArrayN<Complex>
 {
@@ -54,14 +51,6 @@ public:
 
   ComplexNDArray (const MArrayN<Complex>& a) : MArrayN<Complex> (a) { }
 
-  ComplexNDArray (const ArrayN<Complex>& a) : MArrayN<Complex> (a) { }
-
-  explicit ComplexNDArray (const NDArray& a);
-
-  explicit ComplexNDArray (const boolNDArray& a);
-
-  explicit ComplexNDArray (const charNDArray& a);
-
   ComplexNDArray& operator = (const ComplexNDArray& a)
     {
       MArrayN<Complex>::operator = (a);
@@ -87,10 +76,17 @@ public:
   ComplexNDArray prod (int dim = -1) const;
   ComplexNDArray sum (int dim = -1) const;
   ComplexNDArray sumsq (int dim = -1) const;
-  int cat (const ComplexNDArray& ra_arg, int dim, int iidx, int move);
+  ComplexNDArray concat (const ComplexNDArray& rb, const Array<int>& ra_idx);
+  ComplexNDArray concat (const NDArray& rb, const Array<int>& ra_idx);
+
+  ComplexNDArray max (int dim = 0) const;
+  ComplexNDArray max (ArrayN<int>& index, int dim = 0) const;
+  ComplexNDArray min (int dim = 0) const;
+  ComplexNDArray min (ArrayN<int>& index, int dim = 0) const;
 
   ComplexNDArray& insert (const NDArray& a, int r, int c);
   ComplexNDArray& insert (const ComplexNDArray& a, int r, int c);
+  ComplexNDArray& insert (const ComplexNDArray& a, const Array<int>& ra_idx);
   
   NDArray abs (void) const;
 
@@ -105,7 +101,7 @@ public:
 
   ComplexMatrix matrix_value (void) const;
 
-  ComplexNDArray squeeze (void) const { return ArrayN<Complex>::squeeze (); }
+  ComplexNDArray squeeze (void) const { return MArrayN<Complex>::squeeze (); }
 
   static void increment_index (Array<int>& ra_idx,
 			       const dim_vector& dimensions,
@@ -130,6 +126,14 @@ private:
     : MArrayN<Complex> (d, dv) { }
 };
 
+extern ComplexNDArray min (const Complex& c, const ComplexNDArray& m);
+extern ComplexNDArray min (const ComplexNDArray& m, const Complex& c);
+extern ComplexNDArray min (const ComplexNDArray& a, const ComplexNDArray& b);
+
+extern ComplexNDArray max (const Complex& c, const ComplexNDArray& m);
+extern ComplexNDArray max (const ComplexNDArray& m, const Complex& c);
+extern ComplexNDArray max (const ComplexNDArray& a, const ComplexNDArray& b);
+
 NDS_CMP_OP_DECLS (ComplexNDArray, Complex)
 NDS_BOOL_OP_DECLS (ComplexNDArray, Complex)
 
