@@ -20,7 +20,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#if defined (__GNUG__)
+#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
 #pragma implementation
 #endif
 
@@ -31,6 +31,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "Quad.h"
 #include "f77-fcn.h"
 #include "lo-error.h"
+#include "quit.h"
 #include "sun-utils.h"
 
 static integrand_fcn user_fcn;
@@ -44,21 +45,26 @@ int quad_integration_error = 0;
 typedef int (*quad_fcn_ptr) (double*, int&, double*);
 			      
 extern "C"
-int F77_FCN (dqagp, DQAGP) (quad_fcn_ptr, const double&, const double&,
-			    const int&, const double*, const double&,
-			    const double&, double&, double&, int&,
-			    int&, const int&, const int&, int&, int*,
-			    double*);
+{
+  F77_RET_T
+  F77_FUNC (dqagp, DQAGP) (quad_fcn_ptr, const double&, const double&,
+			   const int&, const double*, const double&,
+			   const double&, double&, double&, int&,
+			   int&, const int&, const int&, int&, int*,
+			   double*);
 
-extern "C"
-int F77_FCN (dqagi, DQAGI) (quad_fcn_ptr, const double&, const int&,
-			    const double&, const double&, double&,
-			    double&, int&, int&, const int&,
-			    const int&, int&, int*, double*); 
+  F77_RET_T
+  F77_FUNC (dqagi, DQAGI) (quad_fcn_ptr, const double&, const int&,
+			   const double&, const double&, double&,
+			   double&, int&, int&, const int&,
+			   const int&, int&, int*, double*); 
+}
 
 static int
 user_function (double *x, int& ierr, double *result)
 {
+  BEGIN_INTERRUPT_WITH_EXCEPTIONS;
+
 #if defined (sun) && defined (__GNUC__)
   double xx = access_double (x);
 #else
@@ -78,6 +84,8 @@ user_function (double *x, int& ierr, double *result)
   if (quad_integration_error)
     ierr = -1;
 
+  END_INTERRUPT_WITH_EXCEPTIONS;
+
   return 0;
 }
 
