@@ -23,7 +23,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_ColumnVector_h)
 #define octave_ColumnVector_h 1
 
-#if defined (__GNUG__)
+#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
 #pragma interface
 #endif
 
@@ -73,6 +73,8 @@ public:
 
   ColumnVector extract (int r1, int r2) const;
 
+  ColumnVector extract_n (int r1, int n) const;
+
   // matrix by column vector -> column vector operations
 
   friend ColumnVector operator * (const Matrix& a, const ColumnVector& b);
