@@ -59,8 +59,8 @@ IDX_VEC_REP::idx_vector_rep (const IDX_VEC_REP& a)
     }
 }
 
-static inline int
-tree_to_mat_idx (double x, bool& conversion_error)
+int
+IDX_VEC_REP::tree_to_mat_idx (double x, bool& conversion_error)
 {
   int retval = -1;
 
@@ -79,12 +79,6 @@ tree_to_mat_idx (double x, bool& conversion_error)
   return retval;
 }
 
-static inline int
-tree_to_mat_idx (int i)
-{
-  return i - 1;
-}
-
 static inline bool
 idx_is_inf_or_nan (double x)
 {
