@@ -378,11 +378,12 @@ OP_DUP_FCN (conj, mx_inline_conj_dup, Complex, Complex)
      break; \
    } 
  
-#define MX_ND_REDUCTION(EVAL_EXPR, END_EXPR, VAL, ACC_DECL, RET_TYPE) \
+#define MX_ND_REDUCTION(EVAL_EXPR, END_EXPR, VAL, ACC_DECL, \
+                        RET_TYPE, RET_ELT_TYPE) \
  \
   RET_TYPE retval; \
  \
-  dim_vector dv = dims (); \
+  dim_vector dv = this->dims (); \
  \
   int empty = true; \
  \
@@ -453,10 +454,10 @@ OP_DUP_FCN (conj, mx_inline_conj_dup, Complex, Complex)
     dv(dim) = 1; \
  \
   /* This finds the number of elements in retval */ \
-  int num_iter = (numel () / dim_length); \
+  int num_iter = (this->numel () / dim_length); \
  \
   /* Make sure retval has correct dimensions */ \
-  retval.resize (dv, false); \
+  retval.resize (dv, RET_ELT_TYPE ()); \
  \
   Array<int> iter_idx (dv.length (), 0); \
  \
@@ -481,32 +482,33 @@ OP_DUP_FCN (conj, mx_inline_conj_dup, Complex, Complex)
  \
       increment_index (iter_idx, dv); \
     } \
+ \
+  retval.chop_trailing_singletons (); \
  \
   return retval
 
 #define MX_ND_REAL_OP_REDUCTION(ASN_EXPR, INIT_VAL) \
   MX_ND_REDUCTION (acc ASN_EXPR, retval.elem (iter_idx) = acc, \
-                   INIT_VAL, double acc = INIT_VAL, NDArray)
+                   INIT_VAL, double acc = INIT_VAL, NDArray, double)
 
 #define MX_ND_COMPLEX_OP_REDUCTION(ASN_EXPR, INIT_VAL) \
   MX_ND_REDUCTION (acc ASN_EXPR, retval.elem (iter_idx) = acc, \
-                   INIT_VAL, Complex acc = INIT_VAL, ComplexNDArray)
+                   INIT_VAL, Complex acc = INIT_VAL, ComplexNDArray, Complex)
 
 #define MX_ND_ANY_ALL_REDUCTION(EVAL_EXPR, VAL) \
-  MX_ND_REDUCTION (EVAL_EXPR, , VAL, , boolNDArray)
+  MX_ND_REDUCTION (EVAL_EXPR, , VAL, , boolNDArray, bool)
 
 #define MX_ND_CUMULATIVE_OP(RET_TYPE, ACC_TYPE, VAL, OP) \
   RET_TYPE retval; \
  \
-  dim_vector dv = dims (); \
+  dim_vector dv = this->dims (); \
  \
   int empty = true; \
  \
   /* If dim is larger then number of dims, return array as is */ \
-  if (dim > dv.length ()) \
+  if (dim >= dv.length ()) \
     { \
       retval = RET_TYPE (*this); \
- \
       return retval; \
     } \
  \
@@ -523,7 +525,6 @@ OP_DUP_FCN (conj, mx_inline_conj_dup, Complex, Complex)
   if (empty) \
     { \
       retval.resize (dv); \
- \
       return retval; \
     } \
  \
@@ -559,7 +560,6 @@ OP_DUP_FCN (conj, mx_inline_conj_dup, Complex, Complex)
   if (squeezed) \
     {  \
       retval.resize (dv); \
- \
       return retval; \
     } \
  \
@@ -574,7 +574,7 @@ OP_DUP_FCN (conj, mx_inline_conj_dup, Complex, Complex)
   dv (dim) = 1; \
  \
   /* This finds the number of elements in retval */ \
-  int num_iter = (numel () / dim_length); \
+  int num_iter = (this->numel () / dim_length); \
  \
   Array<int> iter_idx (dv.length (), 0); \
  \
