@@ -37,7 +37,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "str-vec.h"
 
 #define NOT_SUPPORTED(nm) \
-  nm ## ": not supported on this system"
+  nm ": not supported on this system"
 
 std::string
 octave_group::name (void) const
@@ -117,7 +117,7 @@ octave_group
 octave_group::getgrnam (const std::string& nm)
 {
   std::string msg;
-  return getgrnam (msg);
+  return getgrnam (nm, msg);
 }
 
 octave_group
@@ -188,6 +188,8 @@ octave_group::octave_group (void *p, std::string& msg)
       gr_passwd = gr->gr_passwd;
 #endif
 
+      gr_gid = gr->gr_gid;
+
       // XXX FIXME XXX -- maybe there should be a string_vector
       // constructor that takes a NULL terminated list of C
       // strings.
