@@ -34,6 +34,10 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #endif
 
+#if defined (OCTAVE_USE_WINDOWS_API)
+#include <windows.h>
+#endif
+
 #include "lo-error.h"
 #include "lo-utils.h"
 #include "oct-time.h"
@@ -52,7 +56,7 @@ octave_time::octave_time (const octave_base_tm& tm)
   t.tm_yday = tm.yday ();
   t.tm_isdst = tm.isdst ();
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
   std::string s = tm.zone ();
   char *ps = strsave (s.c_str ());
   t.tm_zone = ps;
@@ -60,7 +64,7 @@ octave_time::octave_time (const octave_base_tm& tm)
 
   ot_unix_time = mktime (&t);
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
   delete [] ps;
 #endif
 
@@ -87,9 +91,75 @@ octave_time::stamp (void)
 #endif
 
   ot_unix_time = tp.tv_sec;
-
   ot_usec = tp.tv_usec;
 
+#elif defined (OCTAVE_USE_WINDOWS_API)
+
+  // Loosely based on the code from Cygwin
+  // Copyright 1996-2002 Red Hat, Inc.
+  // Licenced under the GPL.
+
+  const LONGLONG TIME_OFFSET = 0x19db1ded53e8000LL;
+
+  static int init = 1;
+  static LARGE_INTEGER base;
+  static LARGE_INTEGER t0;
+  static double dt;
+
+  if (init)
+    {
+      LARGE_INTEGER ifreq;
+
+      if (QueryPerformanceFrequency (&ifreq))
+        {
+	  // Get clock frequency
+	  dt = (double) 1000000.0 / (double) ifreq.QuadPart;
+
+	  // Get base time as microseconds from Jan 1. 1970
+	  int priority = GetThreadPriority (GetCurrentThread ());
+	  SetThreadPriority (GetCurrentThread(), THREAD_PRIORITY_TIME_CRITICAL);
+	  if (QueryPerformanceCounter (&base))
+	    {
+	      FILETIME f;
+
+	      GetSystemTimeAsFileTime (&f);
+
+	      t0.HighPart = f.dwHighDateTime;
+	      t0.LowPart = f.dwLowDateTime;
+	      t0.QuadPart -= TIME_OFFSET;
+	      t0.QuadPart /= 10;
+
+	      init = 0;
+	    }
+
+	  SetThreadPriority (GetCurrentThread (), priority);
+	}
+
+      if (! init)
+	{
+	  ot_unix_time = time (0);
+	  ot_usec = 0;
+
+	  return;
+	}
+    }
+
+  LARGE_INTEGER now;
+
+  if (QueryPerformanceCounter (&now))
+    {
+      now.QuadPart = (LONGLONG) (dt * (double)(now.QuadPart - base.QuadPart));
+      now.QuadPart += t0.QuadPart;
+
+      ot_unix_time = now.QuadPart / 1000000LL;
+      ot_usec = now.QuadPart % 1000000LL;
+    }
+  else
+    {
+      ot_unix_time = time (0);
+      ot_usec = 0;
+    }
+
 #else
 
   ot_unix_time = time (0);
@@ -175,7 +245,7 @@ octave_base_tm::strftime (const std::string& fmt) const
       t.tm_yday = tm_yday;
       t.tm_isdst = tm_isdst;
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
       char *ps = strsave (tm_zone.c_str ());
       t.tm_zone = ps;
 #endif
@@ -197,7 +267,7 @@ octave_base_tm::strftime (const std::string& fmt) const
 	  bufsize *= 2;
 	}
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
       delete [] ps;
 #endif
 
@@ -224,7 +294,7 @@ octave_base_tm::init (void *p)
   tm_yday = t->tm_yday;
   tm_isdst = t->tm_isdst;
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
   tm_zone = t->tm_zone;
 #elif defined (HAVE_TZNAME)
   if (t->tm_isdst == 0 || t->tm_isdst == 1)
@@ -267,7 +337,7 @@ octave_strptime::init (const std::string& str, const std::string& fmt)
   t.tm_yday = 0;
   t.tm_isdst = 0;
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
   char *ps = strsave ("");
   t.tm_zone = ps;
 #endif
@@ -282,7 +352,7 @@ octave_strptime::init (const std::string& str, const std::string& fmt)
 
   octave_base_tm::init (&t);
 
-#if defined (HAVE_TM_ZONE)
+#if defined (HAVE_STRUCT_TM_TM_ZONE)
   delete ps;
 #endif
 }
