@@ -72,7 +72,8 @@ public:
 
   string_vector find_all (const std::string&);
 
-  static void set_program_name (const std::string&);
+  std::string find_first_of (const string_vector& names);
+  string_vector find_all_first_of (const string_vector& names);
 
   void rehash (void)
     {
