@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,11 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: setaudio ([w_type [, value]])
+## -*- texinfo -*-
+## @deftypefn{Function File} setaudio ([@var{w_type} [, @var{value}]])
 ##
-## executes the shell command `mixer [w_type [, value]]'
+## executes the shell command `mixer [@var{w_type} [, @var{value}]]'
+## @end deftypefn
 
 ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
 ## Created: 5 October 1994
@@ -34,7 +36,7 @@ function setaudio (w_type, value)
   elseif (nargin == 2)
     system (sprintf ("mixer %s %d", w_type, value));
   else
-    usage ("setaudio ([w_type [, value]])");
+    usage ("setaudio (w_type, value)");
   endif
 
 endfunction
