@@ -21,7 +21,7 @@
 ## Returns dc-gain matrix. If dc-gain is infinite
 ## an empty matrix is returned.
 ## The argument @var{tol} is an optional tolerance for the condition
-## number of the @math{A}-Matrix in @var{sys} (default @var{tol} = 1.0e-10)
+## number of the @math{A} Matrix in @var{sys} (default @var{tol} = 1.0e-10)
 ## @end deftypefn
 
 ## Author: Kai P. Mueller <mueller@ifr.ing.tu-bs.de>
