@@ -21,6 +21,7 @@
 ## @deftypefn {Function File} {} @var{rgb_map} = hsv2rgb (@var{hsv_map})
 ## Transform a colormap from the hsv space to the rgb space. 
 ## @end deftypefn
+##
 ## @seealso{rgb2hsv}
 
 ## Author: Kai Habel <kai.habel@gmx.de>
@@ -37,7 +38,7 @@ function rgb_map = hsv2rgb (hsv_map)
     usage ("rgb_map = hsv2rgb (hsv_map)");
   endif
 
-  if (! is_matrix (hsv_map) || columns (hsv_map) != 3)
+  if (! ismatrix (hsv_map) || columns (hsv_map) != 3)
     error ("hsv2rgb: argument must be a matrix of size nx3");
   endif
 
