@@ -1,18 +1,21 @@
 ## Copyright (C) 1995, 1996  Kurt Hornik
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
+## This file is part of Octave.
+##
+## Octave is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## This program is distributed in the hope that it will be useful, but
+## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this file.  If not, write to the Free Software Foundation,
-## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+## along with Octave; see the file COPYING.  If not, write to the Free
+## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+## 02111-1307, USA.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} commutation_matrix (@var{m}, @var{n})
@@ -86,12 +89,12 @@ function k = commutation_matrix (m, n)
   if (nargin < 1 || nargin > 2)
     usage ("commutation_matrix (m, n)");
   else
-    if (! (is_scalar (m) && m == round (m) && m > 0))
+    if (! (isscalar (m) && m == round (m) && m > 0))
       error ("commutation_matrix: m must be a positive integer");
     endif
     if (nargin == 1)
       n = m;
-    elseif (! (is_scalar (n) && n == round (n) && n > 0))
+    elseif (! (isscalar (n) && n == round (n) && n > 0))
       error ("commutation_matrix: n must be a positive integer");
     endif
   endif
