@@ -26,14 +26,14 @@
 ##
 ## @table @asis
 ## @item @var{p} = @code{1}
-## 1-norm, the largest column sum of @var{a}.
+## 1-norm, the largest column sum of the absolute values of @var{a}.
 ##
 ## @item @var{p} = @code{2}
 ## Largest singular value of @var{a}.
 ##
 ## @item @var{p} = @code{Inf}
 ## @cindex infinity norm
-## Infinity norm, the largest row sum of @var{a}.
+## Infinity norm, the largest row sum of the absolute values of @var{a}.
 ##
 ## @item @var{p} = @code{"fro"}
 ## @cindex Frobenius norm
@@ -53,6 +53,7 @@
 ## p-norm of @var{a}, @code{(sum (abs (@var{a}) .^ @var{p})) ^ (1/@var{p})}.
 ## @end table
 ## @end deftypefn
+##
 ## @seealso{cond and svd}
 
 ## Author: jwe
@@ -68,6 +69,10 @@ function retval = norm (x, p)
     return;
   endif
 
+  if (ndims (x) > 2)
+    error ("norm: Only valid on 2-D objects")
+  endif
+
   ## Do we have a vector or matrix as the first argument?
 
   if (rows (x) == 1 || columns (x) == 1)
