@@ -18,13 +18,16 @@
 ## 02111-1307, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{status}, @var{text}]} isunix (@var{command})
-## @deftypefnx {Function File} {[@var{status}, @var{text}]} isunix (@var{command}, "-echo")
+## @deftypefn {Function File} {[@var{status}, @var{text}]} unix (@var{command})
+## @deftypefnx {Function File} {[@var{status}, @var{text}]} unix (@var{command}, "-echo")
 ## Execute a system command if running under a Unix-like operating
 ## system, otherwise do nothing.  Return the exit status of the program
 ## in @var{status} and any output sent to the standard output in
 ## @var{text}.  If the optional second argument @code{"-echo"} is given,
 ## then also send the output from the command to the standard output.
+## @end deftypefn
+##
+## @seealso{isunix, ispc, system}
 
 ## Author: octave-forge ???
 ## Adapted by: jwe
