@@ -23,30 +23,33 @@
 
 ## Author: jwe
 
-function __plt__ (caller, ...)
+function __plt__ (caller, varargin)
 
-  if (nargin == 2)
+  nargs = nargin ();
 
-    __plt1__ (va_arg (), "");
+  if (nargs == 2)
 
-  elseif (nargin > 2)
+    __plt1__ (varargin{1}, "");
+
+  elseif (nargs > 2)
 
     first_plot = 1;
     hold_state = ishold ();
 
     unwind_protect
 
-      x = va_arg ();
-      nargin = nargin - 2;
+      k = 1;
+      x = varargin{k++};
+      nargs -= 2;
       x_set = 1;
       y_set = 0;
 
       ## Gather arguments, decode format, and plot lines.
 
-      while (nargin-- > 0)
+      while (nargs-- > 0)
 
         fmt = "";
-        new = va_arg ();
+        new = varargin{k++};
 
         if (isstr (new))
           if (! x_set)
