@@ -1,4 +1,4 @@
-## Copyright (C) 2000, Teemu Ikonen
+## Copyright (C) 2000, 2001, 2002 Teemu Ikonen
 ##
 ## This file is part of Octave.
 ##
@@ -103,6 +103,7 @@
 ## from @var{y}-@var{ly} to @var{y}+@var{uy}.
 ##
 ## @end deftypefn
+##
 ## @seealso{semilogx, semilogy, loglog, polar, mesh, contour, __pltopt__,
 ## bar, stairs, gplot, gsplot, replot, xlabel, ylabel, and title}
 
@@ -110,75 +111,16 @@
 ## Author: Teemu Ikonen <tpikonen@pcu.helsinki.fi>
 ## Keywords: errorbar, plotting
 
-function errorbar (...)
+function errorbar (varargin)
 
   if (nargin < 2)
     usage ("errorbar (...)");
   endif
 
-  save_hold = ishold;
-  unwind_protect
-    if (! ishold)
-      clg ()
-    endif
-    hold ("on");
-    while (nargin)
-      a = va_arg ();
-      nargin--;
-      if (is_vector (a))
-	a = a(:);
-      elseif (is_matrix (a));
-	;
-      else
-	usage ("errorbar (...)");
-      endif
-      sz = size (a);
-      ndata = 1;
-      arg1 = a;
-      fmt = " ";
-      while (nargin)
-	nargin--;
-	a = va_arg ();
-	if (isstr (a))
-	  fmt = a;
-	  cmd = "__errplot__ (arg1";
-	  for i = 2:ndata,
-	    cmd = [cmd, sprintf(", arg%d",i)];
-	  endfor
-	  cmd = [cmd, ", fmt);"];
-	  eval (cmd);
-	  break;
-	elseif (is_vector (a))
-	  a = a(:);
-	elseif (is_matrix (a))
-	  ;
-	else
-	  error ("wrong argument types");
-	endif
-	if (size (a) != sz)
-	  error ("argument sizes do not match");
-	endif
-	ndata++;
-	eval (sprintf ("arg%d = a;", ndata));
-	if (ndata > 6)
-	  error ("too many arguments to a plot");
-	endif
-      endwhile
-    endwhile
+  gset nologscale x;
+  gset nologscale y;
+  gset nopolar;
 
-    if (! isstr (a))
-      fmt = " ";
-      cmd = "__errplot__(arg1";
-      for i = 2:ndata,
-	cmd = [cmd, sprintf(", arg%d",i)];
-      endfor
-      cmd = [cmd, ", fmt);"];
-      eval (cmd);
-    endif
-  unwind_protect_cleanup
-    if (! save_hold)
-      hold ("off");
-    endif
-  end_unwind_protect
+  __errcomm__ ("errorbar", varargin{:});
 
 endfunction
