@@ -23,12 +23,13 @@
 ## description of @code{plot} for a description of the arguments that
 ## @code{loglog} will accept.
 ## @end deftypefn
+##
 ## @seealso{plot, semilogy, loglog, polar, mesh, contour, bar, stairs,
 ## gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
-function loglog (...)
+function loglog (varargin)
 
   ## XXX FIXME XXX -- these plot states should really just be set
   ## temporarily, probably inside an unwind_protect block, but there is
@@ -38,6 +39,6 @@ function loglog (...)
   gset logscale y;
   gset nopolar;
 
-  __plt__ ("loglog", all_va_args);
+  __plt__ ("loglog", varargin{:});
 
 endfunction
