@@ -32,11 +32,7 @@
 ## Author: Vinayak Dutt <Dutt.Vinayak@mayo.EDU>
 ## Adapted-By: jwe
 
-function mplot (...)
-
-  if (! gnuplot_has_multiplot)
-    error ("mplot: gnuplot does not appear to support this feature");
-  endif
+function mplot (varargin)
 
   ## global variables to keep track of multiplot options
 
@@ -51,7 +47,7 @@ function mplot (...)
   gset nologscale;
   gset nopolar;
 
-  __plt__ ("plot", all_va_args);
+  __plt__ ("plot", varargin{:});
 
   ## update the plot position
 
