@@ -51,11 +51,7 @@
 ## Created: 3 July 95
 ## Adapted-By: jwe
 
-function plot_border (...)
-
-  if (! gnuplot_has_multiplot)
-    error ("plot_border: gnuplot does not appear to support this feature");
-  endif
+function plot_border (varargin)
 
   south = 0;
   west = 0;
@@ -64,11 +60,13 @@ function plot_border (...)
   all = 0;
   none = 1;
 
-  va_start ();
+  k = 1;
 
-  while (nargin--)
+  nargs = nargin ();
 
-    arg = va_arg ();
+  while (nargs--)
+
+    arg = varargin{k++};
 
     if (! isstr (arg))
       error ("plot_border: input not a string");
