@@ -23,12 +23,13 @@
 ## the description of @code{plot} for a description of the arguments
 ## that @code{semilogx} will accept.
 ## @end deftypefn
+##
 ## @seealso{plot, semilogy, loglog, polar, mesh, contour, bar, stairs,
 ## gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
-function semilogx (...)
+function semilogx (varargin)
 
   ## XXX FIXME XXX -- these plot states should really just be set
   ## temporarily, probably inside an unwind_protect block, but there is
@@ -38,6 +39,6 @@ function semilogx (...)
   gset nologscale y;
   gset nopolar;
 
-  __plt__ ("semilogx", all_va_args);
+  __plt__ ("semilogx", varargin{:});
 
 endfunction
