@@ -23,12 +23,13 @@
 ## the description of @code{plot} for a description of the arguments
 ## that @code{semilogy} will accept.
 ## @end deftypefn
+##
 ## @seealso{plot, semilogx, loglog, polar, mesh, contour, bar, stairs,
 ## gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
-function semilogy (...)
+function semilogy (varargin)
 
   ## XXX FIXME XXX -- these plot states should really just be set
   ## temporarily, probably inside an unwind_protect block, but there is
@@ -38,6 +39,6 @@ function semilogy (...)
   gset logscale y;
   gset nopolar;
 
-  __plt__ ("semilogy", all_va_args);
+  __plt__ ("semilogy", varargin{:});
 
 endfunction
