@@ -23,6 +23,14 @@
 ## Sets @code{gnuplot} in multiplot mode and plots in location
 ## given by index (there are @var{cols} by @var{rows} subwindows).
 ##
+## The global variable @var{__multiplot_scale__} should be used when the
+## command @code{gset size xsize, ysize} has been used prior to calling
+## @code{subplot}.
+##
+## The value of @var{__multiplot_scale__} should be a vector with two
+## elements, the first set equal to @var{xsize} and the second to
+## @var{ysize}.
+##
 ## Input:
 ##
 ## @table @var
@@ -74,10 +82,6 @@
 
 function subplot (rows, columns, index)
 
-  if (! gnuplot_has_multiplot)
-    error ("subplot: gnuplot does not appear to support this feature");
-  endif
-
   ## global variables to keep track of multiplot options
 
   global __multiplot_mode__ = 0;
@@ -87,6 +91,11 @@ function subplot (rows, columns, index)
   global __multiplot_yn__;
   global __multiplot_xi__;
   global __multiplot_yi__;
+  global __multiplot_scale__;
+
+  if (isempty (__multiplot_scale__))
+    __multiplot_scale__ = [1, 1];
+  endif
 
   if (nargin != 3 && nargin != 1)
     usage ("subplot (rows, columns, index) or subplot (rcn)");
@@ -94,7 +103,7 @@ function subplot (rows, columns, index)
 
   if (nargin == 1)
 
-    if (! (is_scalar (rows) && rows >= 0))
+    if (! (isscalar (rows) && rows >= 0))
       error ("subplot: input rcn has to be a positive scalar");
     endif
 
@@ -105,7 +114,7 @@ function subplot (rows, columns, index)
     tmp = (tmp - columns) / 10;
     rows = rem (tmp, 10);
 
-  elseif (! (is_scalar (columns) && is_scalar (rows) && is_scalar (index)))
+  elseif (! (isscalar (columns) && isscalar (rows) && isscalar (index)))
     error ("subplot: columns, rows, and index have to be scalars");
   endif
 
@@ -143,8 +152,8 @@ function subplot (rows, columns, index)
       __multiplot_mode__ = 1;
       __multiplot_xn__ = columns;
       __multiplot_yn__ = rows;
-      __multiplot_xsize__ = 1.0 ./ columns;
-      __multiplot_ysize__ = 1.0 ./ rows;
+      __multiplot_xsize__ = __multiplot_scale__(1) ./ columns;
+      __multiplot_ysize__ = __multiplot_scale__(2) ./ rows;
 
       gnuplot_command_replot = "cle;rep";
 
