@@ -26,8 +26,16 @@
 ## Created: 3 July 95
 ## Adapted-By: jwe
 
-function zlabel (...)
+function h = zlabel (varargin)
 
-  __axis_label__ ("zlabel", all_va_args);
+  ## XXX FIXME XXX -- eventually, we will return a graphics handle.  For
+  ## now, return something, so that calls that expect a handle won't
+  ## fail (at least immediately).
+
+  if (nargout > 0)
+    h = __axis_label__ ("zlabel", varargin{:});
+  else
+    __axis_label__ ("zlabel", varargin{:});
+  endif
 
 endfunction
