@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: polyder (p)
-##
-## SEE ALSO: polyderiv
+## -*- texinfo -*-
+## @deftypefn {Function File} {} polyder (@var{c})
+## See polyderiv.
+## @end deftypefn
 
 ## Author: jwe
 
