@@ -17,17 +17,14 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: gammai (a, x)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} gammai (@var{a}, @var{x})
+## This function is provided for compatibility with older versions of
+## Octave.  New programs should use @code{gammainc} instead.
 ##
-## Compute the incomplete gamma function
-##
-##   gammai (a, x) = (\int_0^x exp(-t) t^(a-1) dt) / gamma(a).
-##
-## If a is scalar, then gammai (a, x) is returned for each element of x
-## and vice versa.
-##
-## If neither a nor x is scalar, the sizes of a and x must agree, and
-## gammainc is applied for corresponding elements of x and a.
+## @code{gammai (@var{a}, @var{x})} is the same as @code{gammainc
+## (@var{x}, @var{a})}.
+## @end deftypefn
 
 ## Author: jwe
 ## Created: 30 Jan 1998
