@@ -1,18 +1,21 @@
 ## Copyright (C) 1995, 1996, 1997  Kurt Hornik
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
+## This file is part of Octave.
+##
+## Octave is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## This program is distributed in the hope that it will be useful, but
+## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this file.  If not, write to the Free Software Foundation,
-## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+## along with Octave; see the file COPYING.  If not, write to the Free
+## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+## 02111-1307, USA.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{pval}, @var{ks}, @var{d}] =} kolmogorov_smirnov_test_2 (@var{x}, @var{y}, @var{alt})
@@ -49,7 +52,7 @@ function [pval, ks, d] = kolmogorov_smirnov_test_2 (x, y, alt)
     usage ("[pval, ks] = kolmogorov_smirnov_test_2 (x, y, tol)");
   endif
 
-  if (! (is_vector (x) && is_vector (y)))
+  if (! (isvector (x) && isvector (y)))
     error ("kolmogorov_smirnov_test_2: both x and y must be vectors");
   endif
 
@@ -70,11 +73,12 @@ function [pval, ks, d] = kolmogorov_smirnov_test_2 (x, y, alt)
   count (find (i <= n_x)) = 1 / n_x;
   count (find (i > n_x)) = - 1 / n_y;
 
-  z = cumsum(count);
-  if ( find(diff(s))) 
+  z = cumsum (count);
+  ds = diff (s);
+  if (any (ds == 0))
     ## There are some ties, so keep only those changes.
     warning ("cannot compute correct p-values with ties")
-    elems = [find(diff(s)); n_x + n_y];
+    elems = [find(ds); n_x+n_y];
     z = z(elems);
   endif
   
