@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,20 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: asctime (TMSTRUCT)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} asctime (@var{tm_struct})
+## Convert a time structure to a string using the following five-field
+## format: Thu Mar 28 08:40:14 1996.  For example,
+##
+## @example
+## @group
+## asctime (localtime (time ())
+##      @result{} "Mon Feb 17 01:15:06 1997\n"
+## @end group
+## @end example
+##
+## This is equivalent to @code{ctime (time ())}.
+## @end deftypefn
 
 ## Author: jwe
 
