@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,18 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: date ()
+## -*- texinfo -*-
+## @deftypefn {Function File} {} date ()
+## Return the date as a character string in the form DD-MMM-YY.  For
+## example,
 ##
-## Return current date in a string, in the form `18-Jul-94'.
+## @example
+## @group
+## date ()
+##      @result{} "20-Aug-93"
+## @end group
+## @end example
+## @end deftypefn
 
 ## Author: jwe
 
