@@ -24,6 +24,17 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#if defined (__WIN32__) && ! defined (_POSIX_VERSION)
+
+#include <windows.h>
+
+#else
+
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -39,35 +50,15 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <sys/poll.h>
 #endif
 
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#endif
 
-static void
-do_octave_usleep (unsigned int useconds)
+void
+octave_sleep (unsigned int seconds)
 {
-#if defined (HAVE_USLEEP)
-
-  usleep (useconds);
-
-#elif defined (HAVE_SELECT)
-
-  struct timeval delay;
-
-  delay.tv_sec = 0;
-  delay.tv_usec = useconds;
-
-  select (0, 0, 0, 0, &delay);
-
-#elif defined (HAVE_POLL)
-
-  struct pollfd pfd;
-  int delay = useconds / 1000;
-
-  if (delay > 0)
-    poll (&fd, 0, delay);
-
+#if defined (__WIN32__) && ! defined (_POSIX_VERSION)
+  Sleep (1000 * seconds);
+#else
+  sleep (seconds);
 #endif
 }
 
@@ -78,9 +69,46 @@ octave_usleep (unsigned int useconds)
   unsigned int usec = useconds % 1000000;
 
   if (sec > 0)
-    sleep (sec);
+    octave_sleep (sec);
 
-  do_octave_usleep (usec);
+#if defined (__WIN32__) && ! defined (_POSIX_VERSION)
+
+  /* Round to the nearest millisecond, with a minimum of 1 millisecond
+     if usleep was called with a a non-zero value.  */
+
+  if (usec > 500)
+    Sleep ((usec+500)/1000);
+  else if (usec > 0)
+    Sleep (1);
+  else
+    Sleep (0);
+
+#elif defined (HAVE_USLEEP)
+
+  usleep (usec);
+
+#elif defined (HAVE_SELECT)
+
+  {
+    struct timeval delay;
+
+    delay.tv_sec = 0;
+    delay.tv_usec = usec;
+
+    select (0, 0, 0, 0, &delay);
+  }
+
+#elif defined (HAVE_POLL)
+
+  {
+    struct pollfd pfd;
+    int delay = usec / 1000;
+
+    if (delay > 0)
+      poll (&fd, 0, delay);
+  }
+
+#endif
 }
 
 int
@@ -95,44 +123,10 @@ octave_strncasecmp (const char *s1, const char *s2, size_t n)
   return strncasecmp (s1, s2, n);
 }
 
-char *
-octave_vsnprintf (const char *fmt, va_list args)
+int
+octave_raw_vsnprintf (char *buf, size_t n, const char *fmt, va_list args)
 {
-#if defined (HAVE_VSNPRINTF)
-  size_t size = 100;
-
-  char *buf = malloc (size);
-
-  while (1)
-    {
-      int nchars = vsnprintf (buf, size, fmt, args);
-
-      if (nchars > -1)
-	return buf;
-      else
-	{
-	  size *= 2;
-	  buf = realloc (buf, size);
-	}
-    }
-#else
-  return 0;
-#endif
-}
-
-char *
-octave_snprintf (const char *fmt, ...)
-{
-  char *retval = 0;
-
-  va_list args;
-  va_start (args, fmt);
-
-  retval = octave_vsnprintf (fmt, args);
-
-  va_end (args);
-
-  return retval;
+  return vsnprintf (buf, n, fmt, args);
 }
 
 /*
