@@ -88,15 +88,23 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define DEFUNX(name, fname, args_name, nargout_name, doc) \
   DEFUNX_INTERNAL (name, fname, args_name, nargout_name, false, doc)
 
-// Define a builtin text-style function.
+// Define a builtin command-style function.
 //
 // This is like DEFUN, except that it defines a function that can be
 // called from the Octave language without using parenthesis to
 // surround the arguments). 
 
-#define DEFUN_TEXT(name, args_name, nargout_name, doc) \
+#define DEFCMD(name, args_name, nargout_name, doc) \
   DEFUN_INTERNAL (name, args_name, nargout_name, true, doc)
 
+// For backward compatibility.
+
+#define DEFUN_TEXT DEFCMD
+
+// This is a function with a name that can't be hidden by a variable.
+#define DEFCONSTFUN(name, args_name, nargout_name, doc) \
+  DEFCONSTFUN_INTERNAL (name, args_name, nargout_name, true, doc)
+
 // Define a mapper function.
 //
 //   name is the name of the function, unquoqted.
@@ -120,11 +128,17 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //   c_c_map is a pointer to a function that should be called for
 //     complex arguments that are expected to create complex results.
 //
-//   lo is the lower bound of the range for which real arguments can
-//     become complex.  (e.g., lo == -Inf for sqrt).
+//   lo is the lower bound of the range for which real arguments
+//     return real results (e.g., lo == 0 for sqrt).
 //
-//   hi is the upper bound of the range for which real arguments can
-//     become complex.  (e.g., hi == 0 for sqrt).
+//   hi is the upper bound of the range for which real arguments
+//     return real results (e.g., hi == Inf for sqrt).
+//
+//   ch_map_flag has the following meanings for the ch_map function:
+//
+//     0  =>  this function returns a matrix of ones and zeros
+//     1  =>  this function returns a numeric matrix (any values)
+//     2  =>  this function returns a std::string array
 //
 //   can_ret_cmplx_for_real is a flag that says whether this function
 //     can create a complex number given a real-valued  argument
@@ -132,17 +146,19 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //   doc is the simple help text for the function.
 
-#define DEFUN_MAPPER(name, ch_map, d_b_map, c_b_map, d_d_map, d_c_map, \
-		     c_c_map, lo, hi, can_ret_cmplx_for_real, doc) \
-  DEFUN_MAPPER_INTERNAL(name, ch_map, d_b_map, c_b_map, d_d_map, d_c_map, \
-			c_c_map, lo, hi, can_ret_cmplx_for_real, doc)
+#define DEFUN_MAPPER(name, ch_map, d_b_map, c_b_map, d_d_map, \
+		     d_c_map, c_c_map, lo, hi, ch_map_flag, \
+		     can_ret_cmplx_for_real, doc) \
+  DEFUN_MAPPER_INTERNAL (name, ch_map, d_b_map, c_b_map, d_d_map, \
+			 d_c_map, c_c_map, lo, hi, ch_map_flag, \
+			 can_ret_cmplx_for_real, doc)
 
 // Make alias another name for the existing function name.  This macro
 // must be used in the same file where name is defined, after the
 // definition for name.
 
-#define DEFALIAS(name, alias) \
-  DEFALIAS_INTERNAL (name, alias)
+#define DEFALIAS(alias, name) \
+  DEFALIAS_INTERNAL (alias, name)
 
 #endif
 
