@@ -31,7 +31,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //   sync_system   (now merged with system)
 //   async_system  (now merged with system)
 
-// Completely rewritten by John W. Eaton <jwe@bevo.che.wisc.edu>,
+// Completely rewritten by John W. Eaton <jwe@bevo.che.wics.edu>,
 // April 1996.
 
 #ifdef HAVE_CONFIG_H
@@ -102,48 +102,56 @@ close_files (void)
   octave_stream_list::clear ();
 }
 
+static void
+maybe_warn_interface_change (const std::string& mode)
+{
+  static bool warned = false;
+
+  if (! warned
+      && (mode == "r" || mode == "w" || mode == "a"
+	  || mode == "r+" || mode == "w+" || mode == "a+")
+      && ! is_globally_visible ("__disable_fopen_interface_change_warning__"))
+    {
+      warned = true;
+      warning ("fopen: default open mode is now binary");
+    }
+}
+
 static std::ios::openmode
-fopen_mode_to_ios_mode (const std::string& mode_arg)
+fopen_mode_to_ios_mode (const std::string& mode)
 {
   std::ios::openmode retval = std::ios::in;
 
-  if (! mode_arg.empty ())
+  if (! mode.empty ())
     {
-      std::string mode = mode_arg;
-
-      // Text mode doesn't matter (yet) for Octave.
-
-      size_t pos = mode.find ('t');
-
-      if (pos != NPOS)
-	mode.erase (pos);
-
       // Could probably be faster, but does it really matter?
 
-      if (mode == "r")
+      maybe_warn_interface_change (mode);
+
+      if (mode == "rt")
 	retval = std::ios::in;
-      else if (mode == "w")
+      else if (mode == "wt")
 	retval = std::ios::out | std::ios::trunc;
-      else if (mode == "a")
+      else if (mode == "at")
 	retval = std::ios::out | std::ios::app;
-      else if (mode == "r+")
+      else if (mode == "r+t")
 	retval = std::ios::in | std::ios::out;
-      else if (mode == "w+")
+      else if (mode == "w+t")
 	retval = std::ios::in | std::ios::out | std::ios::trunc;
-      else if (mode == "a+")
+      else if (mode == "a+t")
 	retval = std::ios::in | std::ios::out | std::ios::ate;
-      else if (mode == "rb")
+      else if (mode == "rb" || mode == "r")
 	retval = std::ios::in | std::ios::binary;
-      else if (mode == "wb")
+      else if (mode == "wb" || mode == "w")
 	retval = std::ios::out | std::ios::trunc | std::ios::binary;
-      else if (mode == "ab")
+      else if (mode == "ab" || mode == "a")
 	retval = std::ios::out | std::ios::app | std::ios::binary;
-      else if (mode == "r+b")
+      else if (mode == "r+b" || mode == "r+")
 	retval = std::ios::in | std::ios::out | std::ios::binary;
-      else if (mode == "w+b")
+      else if (mode == "w+b" || mode == "w+")
 	retval = (std::ios::in | std::ios::out | std::ios::trunc
 		  | std::ios::binary);
-      else if (mode == "a+b")
+      else if (mode == "a+b" || mode == "a+")
 	retval = (std::ios::in | std::ios::out | std::ios::ate
 		  | std::ios::binary);
       else
@@ -174,7 +182,8 @@ DEFUN (fclose, args, ,
 @deftypefn {Built-in Function} {} fclose (@var{fid})\n\
 Closes the specified file.  If successful, @code{fclose} returns 0,\n\
 otherwise, it returns -1.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fopen, fseek, ftell}")
 {
   octave_value retval = -1;
 
@@ -195,7 +204,11 @@ Flush output to @var{fid}.  This is useful for ensuring that all\n\
 pending output makes it to the screen before some other event occurs.\n\
 For example, it is always a good idea to flush the standard output\n\
 stream before calling @code{input}.\n\
-@end deftypefn")
+\n\
+@code{fflush} returns 0 on success and an OS dependent error value\n\
+(@minus{}1 on unix) on error.\n\
+@end deftypefn\n\
+@seealso{fopen, fclose}")
 {
   octave_value retval = -1;
 
@@ -238,7 +251,8 @@ If @var{len} is omitted, @code{fgetl} reads until the next newline\n\
 character.\n\
 \n\
 If there are no more characters to read, @code{fgetl} returns @minus{}1.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fread, fscanf}")
 {
   static std::string who = "fgetl";
 
@@ -286,7 +300,8 @@ If @var{len} is omitted, @code{fgets} reads until the next newline\n\
 character.\n\
 \n\
 If there are no more characters to read, @code{fgets} returns @minus{}1.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fread, fscanf}")
 {
   static std::string who = "fgets";
 
@@ -449,6 +464,13 @@ Open or create a file for reading or writing at the end of the\n\
 file.\n\
 @end table\n\
 \n\
+Append a \"t\" to the mode string to open the file in text mode or a\n\
+\"b\" to open in binary mode.  On Windows and Macintosh systems, text\n\
+mode reading and writing automatically converts linefeeds to the\n\
+appropriate line end character for the system (carriage-return linefeed\n\
+on Windows, carriage-returnn on Macintosh).  The default if no mode is\n\
+specified is binary mode.\n\
+\n\
 The parameter @var{arch} is a string specifying the default data format\n\
 for the file.  Valid values for @var{arch} are:\n\
 \n\
@@ -475,7 +497,8 @@ Cray floating format.\n\
 @noindent\n\
 however, conversions are currently only supported for @samp{native}\n\
 @samp{ieee-be}, and @samp{ieee-le} formats.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fclose, fread, fseek}")
 {
   octave_value_list retval;
 
@@ -611,14 +634,18 @@ Move the file pointer to the beginning of the file @var{fid}, returning\n\
 DEFUN (fseek, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} fseek (@var{fid}, @var{offset}, @var{origin})\n\
-Set the file pointer to any location within the file @var{fid}.  The\n\
-pointer is positioned @var{offset} characters from the @var{origin},\n\
+Set the file pointer to any location within the file @var{fid}.\n\
+\n\
+The pointer is positioned @var{offset} characters from the @var{origin},\n\
 which may be one of the predefined variables @code{SEEK_CUR} (current\n\
 position), @code{SEEK_SET} (beginning), or @code{SEEK_END} (end of\n\
-file). If @var{origin} is omitted, @code{SEEK_SET} is assumed.  The\n\
-offset must be zero, or a value returned by @code{ftell} (in which case\n\
-@var{origin} must be @code{SEEK_SET}.\n\
-@end deftypefn")
+file) or strings \"cof\", \"bof\" or \"eof\". If @var{origin} is omitted,\n\
+@code{SEEK_SET} is assumed.  The offset must be zero, or a value returned\n\
+by @code{ftell} (in which case @var{origin} must be @code{SEEK_SET}.\n\
+\n\
+Return 0 on success and -1 on error.\n\
+@end deftypefn\n\
+@seealso{ftell, fopen, fclose}")
 {
   octave_value retval = -1;
 
@@ -647,7 +674,8 @@ DEFUN (ftell, args, ,
 @deftypefn {Built-in Function} {} ftell (@var{fid})\n\
 Return the position of the file pointer as the number of characters\n\
 from the beginning of the file @var{fid}.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fseek, fopen, fclose}")
 {
   octave_value retval = -1;
 
@@ -671,7 +699,8 @@ DEFUN (fprintf, args, nargout,
 @deftypefn {Built-in Function} {} fprintf (@var{fid}, @var{template}, @dots{})\n\
 This function is just like @code{printf}, except that the output is\n\
 written to the stream @var{fid} instead of @code{stdout}.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{printf, sprintf, fread, fscanf, fopen, fclose}")
 {
   static std::string who = "fprintf";
 
@@ -679,8 +708,6 @@ written to the stream @var{fid} instead of @code{stdout}.\n\
 
   int result = -1;
 
-  bool return_char_count = true;
-
   int nargin = args.length ();
 
   if (nargin > 1 || (nargin > 0 && args(0).is_string ()))
@@ -731,11 +758,13 @@ written to the stream @var{fid} instead of @code{stdout}.\n\
 
 DEFUN (printf, args, nargout,
   "-*- texinfo -*-\n\
-@deftypefn {Built-in Function} {} printf (@var{fid}, @var{template}, @dots{})\n\
+@deftypefn {Built-in Function} {} printf (@var{template}, @dots{})\n\
 Print optional arguments under the control of the template string\n\
 @var{template} to the stream @code{stdout}.\n\
+\n\
+Return the number of characters printed.\n\
 @end deftypefn\n\
-@seealso{fprintf and sprintf}")
+@seealso{fprintf, sprintf, scanf}")
 {
   static std::string who = "printf";
 
@@ -779,6 +808,8 @@ DEFUN (fputs, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} fputs (@var{fid}, @var{string})\n\
 Write a string to a file with no formatting.\n\
+\n\
+Return a non-negative number on success and EOF on error.\n\
 @end deftypefn")
 {
   static std::string who = "fputs";
@@ -804,6 +835,8 @@ DEFUN (puts, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} puts (@var{string})\n\
 Write a string to the standard output with no formatting.\n\
+\n\
+Return a non-negative number on success and EOF on error.\n\
 @end deftypefn")
 {
   static std::string who = "puts";
@@ -826,7 +859,8 @@ string.  Unlike the C library function, which requires you to provide a\n\
 suitably sized string as an argument, Octave's @code{sprintf} function\n\
 returns the string, automatically sized to hold all of the items\n\
 converted.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{printf, fprintf, sscanf}")
 {
   static std::string who = "sprintf";
 
@@ -917,7 +951,8 @@ with each conversion specifier in @var{template} corresponding to a\n\
 single scalar return value.  This form is more `C-like', and also\n\
 compatible with previous versions of Octave.  The number of successful\n\
 conversions is returned in @var{count}\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{scanf, sscanf, fread, fprintf}")
 {
   static std::string who = "fscanf";
 
@@ -988,7 +1023,8 @@ DEFUN (sscanf, args, ,
 This is like @code{fscanf}, except that the characters are taken from the\n\
 string @var{string} instead of from a stream.  Reaching the end of the\n\
 string is treated as an end-of-file condition.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fscanf, scanf, sprintf}")
 {
   static std::string who = "sscanf";
 
@@ -1086,7 +1122,8 @@ This is equivalent to calling @code{fscanf} with @var{fid} = @code{stdin}.\n\
 \n\
 It is currently not useful to call @code{scanf} in interactive\n\
 programs.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fscanf, sscanf, printf}")
 {
   int nargin = args.length ();
 
@@ -1116,8 +1153,12 @@ do_fread (octave_stream& os, const octave_value& size_arg,
 
       if (! error_state)
 	{
-	  oct_data_conv::data_type dt
-	    = oct_data_conv::string_to_data_type (prec);
+	  int block_size = 1;
+	  oct_data_conv::data_type input_type;
+	  oct_data_conv::data_type output_type;
+
+	  oct_data_conv::string_to_data_type (prec, block_size,
+					      input_type, output_type);
 
 	  if (! error_state)
 	    {
@@ -1133,7 +1174,8 @@ do_fread (octave_stream& os, const octave_value& size_arg,
 			= oct_mach_info::string_to_float_format (arch);
 
 		      if (! error_state)
-			retval = os.read (size, dt, skip, flt_fmt, count);
+			retval = os.read (size, block_size, input_type,
+					  output_type, skip, flt_fmt, count);
 		    }
 		  else
 		    ::error ("fread: architecture type must be a string");
@@ -1187,73 +1229,113 @@ The optional argument @var{precision} is a string specifying the type of\n\
 data to read and may be one of\n\
 \n\
 @table @code\n\
-@item \"char\"\n\
-@itemx \"char*1\"\n\
-@itemx \"integer*1\"\n\
-@itemx \"int8\"\n\
-Single character.\n\
-\n\
-@item \"signed char\"\n\
-@itemx \"schar\"\n\
+@item \"schar\"\n\
+@itemx \"signed char\"\n\
 Signed character.\n\
 \n\
-@item \"unsigned char\"\n\
-@itemx \"uchar\"\n\
-@itemx \"uint8\"\n\
+@item \"uchar\"\n\
+@itemx \"unsigned char\"\n\
 Unsigned character.\n\
 \n\
-@item \"short\"\n\
-Short integer.\n\
+@item \"int8\"\n\
+@itemx \"integer*1\"\n\
 \n\
-@item \"unsigned short\"\n\
-@itemx \"ushort\"\n\
-Unsigned short integer.\n\
+8-bit signed integer.\n\
 \n\
-@item \"int\"\n\
-Integer.\n\
+@item \"int16\"\n\
+@itemx \"integer*2\"\n\
+16-bit signed integer.\n\
 \n\
-@item \"unsigned int\"\n\
-@itemx \"uint\"\n\
-Unsigned integer.\n\
+@item \"int32\"\n\
+@itemx \"integer*4\"\n\
+32-bit signed integer.\n\
 \n\
-@item \"long\"\n\
-Long integer.\n\
+@item \"int64\"\n\
+@itemx \"integer*8\"\n\
+64-bit signed integer.\n\
 \n\
-@item \"unsigned long\"\n\
-@itemx \"ulong\"\n\
-Unsigned long integer.\n\
+@item \"uint8\"\n\
+8-bit unsigned integer.\n\
 \n\
-@item \"float\"\n\
+@item \"uint16\"\n\
+16-bit unsigned integer.\n\
+\n\
+@item \"uint32\"\n\
+32-bit unsigned integer.\n\
+\n\
+@item \"uint64\"\n\
+64-bit unsigned integer.\n\
+\n\
+@item \"single\"\n\
 @itemx \"float32\"\n\
 @itemx \"real*4\"\n\
-Single precision float.\n\
+32-bit floating point number.\n\
 \n\
 @item \"double\"\n\
 @itemx \"float64\"\n\
 @itemx \"real*8\"\n\
-Double precision float.\n\
+64-bit floating point number.\n\
 \n\
-@item \"integer*2\"\n\
-@itemx \"int16\"\n\
-Two byte signed integer.\n\
+@item \"char\"\n\
+@itemx \"char*1\"\n\
+Single character.\n\
 \n\
-@item \"integer*4\"\n\
-@itemx \"int32\"\n\
-Four byte signed integer.\n\
+@item \"short\"\n\
+Short integer (size is platform dependent).\n\
 \n\
-@item \"uint16\"\n\
-Two byte unsigned integer.\n\
+@item \"int\"\n\
+Integer (size is platform dependent).\n\
 \n\
-@item \"uint32\"\n\
-Four byte unsigned integer.\n\
+@item \"long\"\n\
+Long integer (size is platform dependent).\n\
+\n\
+@item \"ushort\"\n\
+@itemx \"unsigned short\"\n\
+Unsigned short integer (size is platform dependent).\n\
+\n\
+@item \"uint\"\n\
+@itemx \"unsigned int\"\n\
+Unsigned integer (size is platform dependent).\n\
+\n\
+@item \"ulong\"\n\
+@itemx \"unsigned long\"\n\
+Unsigned long integer (size is platform dependent).\n\
+\n\
+@item \"float\"\n\
+Single precision floating point number (size is platform dependent).\n\
 @end table\n\
 \n\
 @noindent\n\
 The default precision is @code{\"uchar\"}.\n\
 \n\
+The @var{precision} argument may also specify an optional repeat\n\
+count.  For example, @samp{32*single} causes @code{fread} to read\n\
+a block of 32 single precision floating point numbers.  Reading in\n\
+blocks is useful in combination with the @var{skip} argument.\n\
+\n\
+The @var{precision} argument may also specify a type conversion.\n\
+For example, @samp{int16=>int32} causes @code{fread} to read 16-bit\n\
+integer values and return an array of 32-bit integer values.  By\n\
+default, @code{fread} returns a double precision array.  The special\n\
+form @samp{*TYPE} is shorthand for @samp{TYPE=>TYPE}.\n\
+\n\
+The conversion and repeat counts may be combined.  For example,\n\
+@samp{32*single=>single} causes @code{fread} to read blocks of single\n\
+precision floating point values and return an array of single precision\n\
+values instead of the default array of double precision values.\n\
+\n\
 The optional argument @var{skip} specifies the number of bytes to skip\n\
-after each element is read.  If it is not specified, a value of 0 is\n\
-assumed.\n\
+after each element (or block of elements) is read.  If it is not\n\
+specified, a value of 0 is assumed.  If the final block read is not\n\
+complete, the final skip is omitted.  For example,\n\
+\n\
+@example\n\
+fread (f, 10, \"3*single=>single\", 8)\n\
+@end example\n\
+\n\
+@noindent\n\
+will omit the final 8-byte skip because the last read will not be\n\
+a complete block of 3 values.\n\
 \n\
 The optional argument @var{arch} is a string specifying the data format\n\
 for the file.  Valid values are\n\
@@ -1284,7 +1366,8 @@ Conversions are currently only supported for @code{\"ieee-be\"} and\n\
 \n\
 The data read from the file is returned in @var{val}, and the number of\n\
 values read is returned in @code{count}\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fwrite, fopen, fclose}")
 {
   octave_value_list retval;
 
@@ -1343,8 +1426,10 @@ do_fwrite (octave_stream& os, const octave_value& data,
 
   if (! error_state)
     {
-      oct_data_conv::data_type dt
-	= oct_data_conv::string_to_data_type (prec);
+      int block_size = 1;
+      oct_data_conv::data_type output_type;
+
+      oct_data_conv::string_to_data_type (prec, block_size, output_type);
 
       if (! error_state)
 	{
@@ -1360,7 +1445,8 @@ do_fwrite (octave_stream& os, const octave_value& data,
 		    = oct_mach_info::string_to_float_format (arch);
 
 		  if (! error_state)
-		    retval = os.write (data, dt, skip, flt_fmt);
+		    retval = os.write (data, block_size, output_type,
+				       skip, flt_fmt);
 		}
 	      else
 		::error ("fwrite: architecture type must be a string");
@@ -1392,7 +1478,8 @@ optional, and are interpreted as described for @code{fread}.\n\
 \n\
 The behavior of @code{fwrite} is undefined if the values in @var{data}\n\
 are too large to fit in the specified precision.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fread, fopen, fclose}")
 {
   octave_value retval = -1;
 
@@ -1433,7 +1520,8 @@ Return 1 if an end-of-file condition has been encountered for a given\n\
 file and 0 otherwise.  Note that it will only return 1 if the end of the\n\
 file has already been encountered, not if the next read operation will\n\
 result in an end-of-file condition.\n\
-@end deftypefn")
+@end deftypefn\n\
+@seealso{fread, fopen, fclose}")
 {
   octave_value retval = -1;
 
@@ -1690,7 +1778,7 @@ DEFUN (mkstemp, args, ,
 @deftypefn {Built-in Function} {[@var{fid}, @var{name}, @var{msg}] =} tmpfile (@var{template}, @var{delete})\n\
 Return the file ID corresponding to a new temporary file with a unique\n\
 name created from @var{template}.  The last six characters of @var{template}\n\
-must be @code{XXXXXX} and tehse are replaced with a string that makes the\n\
+must be @code{XXXXXX} and these are replaced with a string that makes the\n\
 filename unique.  The file is then created with mode read/write and\n\
 permissions that are system dependent (on GNU/Linux systems, the permissions\n\
 will be 0600 for versions of glibc 2.0.7 and later).  The file is opened\n\
@@ -1867,7 +1955,7 @@ symbols_of_file_io (void)
     "-*- texinfo -*-\n\
 @defvr {Built-in Variable} P_tmpdir\n\
 The default name of the directory for temporary files on this system.\n\
-of this variable is system dependent.\n\
+The value of this variable is system dependent.\n\
 @end defvr");
 
   // NOTE: the values of SEEK_SET, SEEK_CUR, and SEEK_END have to be
