@@ -116,9 +116,11 @@ Octave_map
 
   Octave_map reshape (const dim_vector& new_dims) const;
 
+  Octave_map resize (const dim_vector& dv) const;
+
   int numel (void) const;
 
-  int cat (const Octave_map& ra_arg, int dim, int iidx, int move);
+  Octave_map concat (const Octave_map& rb, const Array<int>& ra_idx);
 
   Octave_map& assign (const octave_value_list& idx, const Octave_map& rhs);
 
