@@ -70,6 +70,8 @@ public:
   octave_value *clone (void) const { return new octave_base_matrix (*this); }
   octave_value *empty_clone (void) const { return new octave_base_matrix (); }
 
+  size_t byte_size (void) const { return matrix.byte_size (); }
+
   octave_value squeeze (void) const { return matrix.squeeze (); }
 
   octave_value subsref (const std::string& type,
@@ -101,6 +103,9 @@ public:
   octave_value permute (const Array<int>& vec, bool inv = false) const
     { return MT (matrix.permute (vec, inv)); }
 
+  octave_value resize (const dim_vector& dv) const
+    { MT retval (matrix); retval.resize (dv); return retval; }
+
   octave_value all (int dim = 0) const { return matrix.all (dim); }
   octave_value any (int dim = 0) const { return matrix.any (dim); }
 
