@@ -142,7 +142,7 @@ octave_bool_matrix::complex_value (bool) const
 octave_value
 octave_bool_matrix::convert_to_str_internal (bool pad, bool force) const
 {
-  octave_value tmp = octave_value (matrix_value ());
+  octave_value tmp = octave_value (array_value ());
   return tmp.convert_to_str (pad, force);
 }
 
@@ -304,7 +304,7 @@ octave_bool_matrix::load_binary (std::istream& is, bool swap,
   if (! is.read (X_CAST (char *, &mdims), 4))
     return false;
   if (swap)
-    swap_4_bytes (X_CAST (char *, &mdims));
+    swap_bytes<4> (&mdims);
   if (mdims >= 0)
     return false;
 
@@ -321,7 +321,7 @@ octave_bool_matrix::load_binary (std::istream& is, bool swap,
       if (! is.read (X_CAST (char *, &di), 4))
 	return false;
       if (swap)
-	swap_4_bytes (X_CAST (char *, &di));
+	swap_bytes<4> (&di);
       dv(i) = di;
     }
   
@@ -339,6 +339,7 @@ octave_bool_matrix::load_binary (std::istream& is, bool swap,
 }
 
 #if defined (HAVE_HDF5)
+
 bool
 octave_bool_matrix::save_hdf5 (hid_t loc_id, const char *name,
 			       bool /* save_as_floats */)
@@ -447,6 +448,7 @@ octave_bool_matrix::load_hdf5 (hid_t loc_id, const char *name,
 
   return retval;
 }
+
 #endif
 
 /*
