@@ -36,6 +36,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "oct-alloc.h"
 
 #include "error.h"
+#include "oct-stream.h"
 #include "ov-base.h"
 #include "ov-base-mat.h"
 #include "ov-typeinfo.h"
@@ -78,8 +79,6 @@ public:
 
   idx_vector index_vector (void) const { return idx_vector (matrix); }
 
-  size_t byte_size (void) const { return numel () * sizeof (bool); }
-
   bool is_bool_matrix (void) const { return true; }
 
   bool is_bool_type (void) const { return true; }
@@ -105,7 +104,7 @@ public:
     { return ComplexMatrix (matrix.matrix_value ( )); }
 
   ComplexNDArray complex_array_value (bool = false) const
-    { return ComplexNDArray (matrix.matrix_value ()); }
+    { return ComplexNDArray (matrix); }
 
   boolMatrix bool_matrix_value (void) const
     { return matrix.matrix_value (); }
@@ -133,6 +132,11 @@ public:
   bool load_hdf5 (hid_t loc_id, const char *name, bool have_h5giterate_bug);
 #endif
 
+  int write (octave_stream& os, int block_size,
+	     oct_data_conv::data_type output_type, int skip,
+	     oct_mach_info::float_format flt_fmt) const
+    { return os.write (matrix, block_size, output_type, skip, flt_fmt); }
+
 protected:
 
   DECLARE_OCTAVE_ALLOCATOR
