@@ -91,7 +91,7 @@ octave_builtin::subsref (const std::string& type,
   // for exmaple?
 
   if (idx.size () > 1)
-    retval = retval(0).next_subsref (type, idx);
+    retval = retval(0).next_subsref (nargout, type, idx);
 
   return retval;
 }
@@ -108,12 +108,17 @@ octave_builtin::do_multi_index_op (int nargout, const octave_value_list& args)
     ::error ("invalid use of colon in function argument list");
   else
     {
+      unwind_protect::begin_frame ("builtin_func_eval");
+
       unwind_protect_ptr (curr_function);
+      unwind_protect_ptr (curr_caller_function);
+
+      curr_caller_function = curr_function;
       curr_function = this;
 
       retval = (*f) (args, nargout);
 
-      unwind_protect::run ();
+      unwind_protect::run_frame ("builtin_func_eval");
     }
 
   return retval;
