@@ -58,16 +58,16 @@ DEFINE_OCTAVE_ALLOCATOR (octave_cell);
 
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_cell, "cell", "cell");
 
-octave_value
+octave_value_list
 octave_cell::subsref (const std::string& type,
-		      const std::list<octave_value_list>& idx)
+		      const std::list<octave_value_list>& idx, int nargout)
 {
-  octave_value retval;
+  octave_value_list retval;
 
   switch (type[0])
     {
     case '(':
-      retval = do_index_op (idx.front ());
+      retval(0) = do_index_op (idx.front ());
       break;
 
     case '{':
@@ -79,7 +79,7 @@ octave_cell::subsref (const std::string& type,
 	    Cell tcell = tmp.cell_value ();
 
 	    if (tcell.length () == 1)
-	      retval = tcell(0,0);
+	      retval(0) = tcell(0,0);
 	    else
 	      {
 		int n = tcell.numel ();
@@ -92,7 +92,7 @@ octave_cell::subsref (const std::string& type,
 		    lst(i) = tcell(i);
 		  }
 
-		retval = octave_value (lst, true);
+		retval(0) = octave_value (lst, true);
 	      }
 	  }
       }
@@ -109,7 +109,14 @@ octave_cell::subsref (const std::string& type,
       panic_impossible ();
     }
 
-  return retval.next_subsref (type, idx);
+  // XXX FIXME XXX -- perhaps there should be an
+  // octave_value_list::next_subsref member function?  See also
+  // octave_user_function::subsref.
+
+  if (idx.size () > 1)
+    retval = retval(0).next_subsref (nargout, type, idx);
+
+  return retval;
 }
 
 octave_value
@@ -201,7 +208,10 @@ octave_cell::subsasgn (const std::string& type,
 	    if (t_rhs.is_cell ())
 	      octave_base_matrix<Cell>::assign (i, t_rhs.cell_value ());
 	    else
-	      octave_base_matrix<Cell>::assign (i, Cell (t_rhs));
+	      if (t_rhs.is_empty ())
+		octave_base_matrix<Cell>::assign (i, Cell());
+	      else
+		octave_base_matrix<Cell>::assign (i, Cell (t_rhs));
 
 	    retval = octave_value (this, count + 1);
 	  }
@@ -631,7 +641,7 @@ octave_cell::load_binary (std::istream& is, bool swap,
   if (! is.read (X_CAST (char *, &mdims), 4))
     return false;
   if (swap)
-    swap_4_bytes (X_CAST (char *, &mdims));
+    swap_bytes<4> (&mdims);
   if (mdims >= 0)
     return false;
 
@@ -645,7 +655,7 @@ octave_cell::load_binary (std::istream& is, bool swap,
       if (! is.read (X_CAST (char *, &di), 4))
 	return false;
       if (swap)
-	swap_4_bytes (X_CAST (char *, &di));
+	swap_bytes<4> (&di);
       dv(i) = di;
     }
   
@@ -718,7 +728,7 @@ octave_cell::save_hdf5 (hid_t loc_id, const char *name, bool save_as_floats)
   OCTAVE_LOCAL_BUFFER (int, hdims, rank);
 
   // Octave uses column-major, while HDF5 uses row-major ordering
-  for (int i = 0; i < rank; i++)
+  for (hsize_t i = 0; i < rank; i++)
     hdims[i] = dv(rank-i-1);
 
   size_hid = H5Dcreate (data_hid, "dims", H5T_NATIVE_INT, space_hid, 
@@ -830,7 +840,9 @@ octave_cell::load_hdf5 (hid_t loc_id, const char *name,
 
 #ifdef HAVE_H5GGET_NUM_OBJS
   hsize_t num_obj = 0;
-  H5Gget_num_objs (loc_id, &num_obj);
+  group_id = H5Gopen (loc_id, name); 
+  H5Gget_num_objs (group_id, &num_obj);
+  H5Gclose (group_id);
 #endif
 
   for (int i = 0; i < dv.numel (); i++)
