@@ -31,11 +31,14 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <iostream>
 #include <vector>
 
+#include "data-conv.h"
 #include "lo-ieee.h"
 #include "mx-base.h"
+#include "mach-info.h"
 
 #include "gripes.h"
 #include "oct-obj.h"
+#include "oct-stream.h"
 #include "ops.h"
 #include "ov-base.h"
 #include "ov-base-mat.h"
@@ -84,6 +87,8 @@ octave_complex_matrix::try_narrowing_conversion (void)
       else if (cm.all_elements_are_real ())
 	retval = new octave_matrix (::real (cm));
     }
+  else if (matrix.all_elements_are_real ())
+    retval = new octave_matrix (::real (matrix));
 
   return retval;
 }
@@ -390,7 +395,7 @@ octave_complex_matrix::load_binary (std::istream& is, bool swap,
   if (! is.read (X_CAST (char *, &mdims), 4))
     return false;
   if (swap)
-    swap_4_bytes (X_CAST (char *, &mdims));
+    swap_bytes<4> (&mdims);
   if (mdims < 0)
     {
       mdims = - mdims;
@@ -403,7 +408,7 @@ octave_complex_matrix::load_binary (std::istream& is, bool swap,
 	  if (! is.read (X_CAST (char *, &di), 4))
 	    return false;
 	  if (swap)
-	    swap_4_bytes (X_CAST (char *, &di));
+	    swap_bytes<4> (&di);
 	  dv(i) = di;
 	}
 
@@ -425,7 +430,7 @@ octave_complex_matrix::load_binary (std::istream& is, bool swap,
       if (! is.read (X_CAST (char *, &nc), 4))
 	return false;
       if (swap)
-	swap_4_bytes (X_CAST (char *, &nc));
+	swap_bytes<4> (&nc);
       if (! is.read (X_CAST (char *, &tmp), 1))
 	return false;
       ComplexMatrix m (nr, nc);
@@ -441,6 +446,7 @@ octave_complex_matrix::load_binary (std::istream& is, bool swap,
 }
 
 #if defined (HAVE_HDF5)
+
 bool
 octave_complex_matrix::save_hdf5 (hid_t loc_id, const char *name,
 				  bool save_as_floats)
@@ -596,6 +602,7 @@ octave_complex_matrix::load_hdf5 (hid_t loc_id, const char *name,
 
   return retval;
 }
+
 #endif
 
 void
