@@ -20,7 +20,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#if defined (__GNUG__)
+#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
 #pragma implementation
 #endif
 
@@ -29,12 +29,20 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 
 #include "error.h"
+#include "oct-obj.h"
 #include "ov-fcn.h"
 
 DEFINE_OCTAVE_ALLOCATOR (octave_function);
 
-octave_function *
-octave_function::clone (void)
+octave_value *
+octave_function::clone (void) const
+{
+  panic_impossible ();
+  return 0;
+}
+
+octave_value *
+octave_function::empty_clone (void) const
 {
   panic_impossible ();
   return 0;
