@@ -265,8 +265,12 @@ octave_mapper::subsref (const std::string& type,
 
   return retval;
 
-  // XXX FIXME XXX
-  //  return retval.next_subsref (type, idx);
+  // XXX FIXME XXX -- perhaps there should be an
+  // octave_value_list::next_subsref member function?  See also
+  // and octave_builtin::subsref.
+
+  if (idx.size () > 1)
+    retval = retval(0).next_subsref (nargout, type, idx);
 }
 
 octave_value_list
@@ -287,12 +291,17 @@ octave_mapper::do_multi_index_op (int, const octave_value_list& args)
     {
       if (args(0).is_defined ())
 	{
+	  unwind_protect::begin_frame ("mapper_func_eval");
+
 	  unwind_protect_ptr (curr_function);
+	  unwind_protect_ptr (curr_caller_function);
+
+	  curr_caller_function = curr_function;
 	  curr_function = this;
 
 	  retval = apply (args(0));
 
-	  unwind_protect::run ();
+	  unwind_protect::run_frame ("mapper_func_eval");
 	}
       else
 	::error ("%s: argument undefined", name().c_str ());
