@@ -82,10 +82,18 @@ public:
   bool is_real_type (void) const { return true; }
 
   bool valid_as_scalar_index (void) const
-    { return (! xisnan (scalar) && NINT (scalar) == 1); }
+    {
+      return (! xisnan (scalar)
+	      && D_NINT (scalar) == scalar
+	      && NINT (scalar) == 1);
+    }
 
   bool valid_as_zero_index (void) const
-    { return (! xisnan (scalar) && NINT (scalar) == 0); }
+    {
+      return (! xisnan (scalar)
+	      && D_NINT (scalar) == scalar
+	      && NINT (scalar) == 0);
+    }
 
   double double_value (bool = false) const { return scalar; }
 
@@ -97,6 +105,16 @@ public:
   NDArray array_value (bool = false) const
     { return NDArray (dim_vector (1, 1), scalar); }
 
+  octave_value resize (const dim_vector& dv) const
+    {
+      NDArray retval (dv);
+
+      if (dv.numel ())
+	retval(0) = scalar;
+
+      return retval;
+    }
+
   Complex complex_value (bool = false) const { return scalar; }
 
   ComplexMatrix complex_matrix_value (bool = false) const
@@ -131,6 +149,14 @@ public:
   bool load_hdf5 (hid_t loc_id, const char *name, bool have_h5giterate_bug);
 #endif
 
+  int write (octave_stream& os, int block_size,
+	     oct_data_conv::data_type output_type, int skip,
+	     oct_mach_info::float_format flt_fmt) const
+    {
+      return os.write (array_value (), block_size, output_type,
+		       skip, flt_fmt);
+    }
+
 private:
 
   DECLARE_OCTAVE_ALLOCATOR
