@@ -31,11 +31,15 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <iostream>
 #include <vector>
 
+#include "data-conv.h"
 #include "lo-ieee.h"
+#include "mach-info.h"
 #include "mx-base.h"
 
 #include "oct-obj.h"
+#include "oct-stream.h"
 #include "ops.h"
+#include "ov-scalar.h"
 #include "ov-re-mat.h"
 #include "ov-str-mat.h"
 #include "gripes.h"
@@ -54,11 +58,21 @@ DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_char_matrix_str, "string", "char");
 static octave_value *
 default_numeric_conversion_function (const octave_value& a)
 {
+  octave_value *retval = 0;
+
   CAST_CONV_ARG (const octave_char_matrix_str&);
 
   NDArray nda = v.array_value (true);
 
-  return error_state ? 0 : new octave_matrix (nda);
+  if (! error_state)
+    {
+      if (nda.numel () == 1)
+	retval = new octave_scalar (nda(0));
+      else
+	retval = new octave_matrix (nda);
+    }
+
+  return retval;
 }
 
 type_conv_fcn
@@ -82,8 +96,9 @@ octave_char_matrix_str::do_index_op (const octave_value_list& idx,
 	idx_vector i = idx (0).index_vector ();
 	idx_vector j = idx (1).index_vector ();
 
-	retval = octave_value (charNDArray (matrix.index (i, j, resize_ok)),
-			       true);
+	if (! error_state)
+	  retval = octave_value (charNDArray (matrix.index (i, j, resize_ok)),
+				 true);
       }
       break;
 
@@ -91,8 +106,9 @@ octave_char_matrix_str::do_index_op (const octave_value_list& idx,
       {
 	idx_vector i = idx (0).index_vector ();
 
-	retval = octave_value (charNDArray (matrix.index (i, resize_ok)),
-			       true);
+	if (! error_state)
+	  retval = octave_value (charNDArray (matrix.index (i, resize_ok)),
+				 true);
       }
       break;
 
@@ -103,8 +119,9 @@ octave_char_matrix_str::do_index_op (const octave_value_list& idx,
 	for (int i = 0; i < len; i++)
 	  idx_vec(i) = idx(i).index_vector ();
 
-	retval = octave_value (charNDArray (matrix.index (idx_vec, resize_ok)),
-			       true);
+	if (! error_state)
+	  retval = octave_value (charNDArray (matrix.index (idx_vec, resize_ok)),
+				 true);
       }
       break;
     }
@@ -438,7 +455,7 @@ octave_char_matrix_str::load_binary (std::istream& is, bool swap,
   if (! is.read (X_CAST (char *, &elements), 4))
     return false;
   if (swap)
-    swap_4_bytes (X_CAST (char *, &elements));
+    swap_bytes<4> (&elements);
 
   if (elements < 0)
     {
@@ -452,7 +469,7 @@ octave_char_matrix_str::load_binary (std::istream& is, bool swap,
 	  if (! is.read (X_CAST (char *, &di), 4))
 	    return false;
 	  if (swap)
-	    swap_4_bytes (X_CAST (char *, &di));
+	    swap_bytes<4> (&di);
 	  dv(i) = di;
 	}
       
@@ -474,7 +491,7 @@ octave_char_matrix_str::load_binary (std::istream& is, bool swap,
 	  if (! is.read (X_CAST (char *, &len), 4))
 	    return false;
 	  if (swap)
-	    swap_4_bytes (X_CAST (char *, &len));
+	    swap_bytes<4> (&len);
 	  OCTAVE_LOCAL_BUFFER (char, btmp, len+1);
 	  if (! is.read (X_CAST (char *, btmp), len))
 	    return false;
@@ -492,6 +509,7 @@ octave_char_matrix_str::load_binary (std::istream& is, bool swap,
 }
 
 #if defined (HAVE_HDF5)
+
 bool
 octave_char_matrix_str::save_hdf5 (hid_t loc_id, const char *name,
 				   bool /* save_as_floats */)
@@ -703,6 +721,7 @@ octave_char_matrix_str::load_hdf5 (hid_t loc_id, const char *name,
 
   return retval;
 }
+
 #endif
 
 /*
