@@ -97,11 +97,12 @@ gripe_failed_assignment (void)
   error ("assignment to structure element failed");
 }
 
-octave_value
+octave_value_list
 octave_struct::subsref (const std::string& type,
-			const std::list<octave_value_list>& idx)
+			const std::list<octave_value_list>& idx,
+			int nargout)
 {
-  octave_value retval;
+  octave_value_list retval;
 
   int skip = 1;
 
@@ -120,7 +121,7 @@ octave_struct::subsref (const std::string& type,
 	      {
 		Cell t = tmp.index (idx.front ());
 
-		retval = (t.length () == 1) ? t(0) : octave_value (t, true);
+		retval(0) = (t.length () == 1) ? t(0) : octave_value (t, true);
 
 		// We handled two index elements, so tell
 		// next_subsref to skip both of them.
@@ -129,7 +130,7 @@ octave_struct::subsref (const std::string& type,
 	      }
 	  }
 	else
-	  retval = map.index (idx.front ());
+	  retval(0) = map.index (idx.front ());
       }
       break;
 
@@ -137,7 +138,7 @@ octave_struct::subsref (const std::string& type,
       {
 	Cell t = dotref (idx.front ());
 
-	retval = (t.length () == 1) ? t(0) : octave_value (t, true);
+	retval(0) = (t.length () == 1) ? t(0) : octave_value (t, true);
       }
       break;
 
@@ -149,8 +150,12 @@ octave_struct::subsref (const std::string& type,
       panic_impossible ();
     }
 
-  if (! error_state)
-    retval = retval.next_subsref (type, idx, skip);
+  // XXX FIXME XXX -- perhaps there should be an
+  // octave_value_list::next_subsref member function?  See also
+  // octave_user_function::subsref.
+
+  if (idx.size () > 1)
+    retval = retval(0).next_subsref (nargout, type, idx, skip);
 
   return retval;
 }
@@ -510,7 +515,8 @@ If the values are cell arrays, create a structure array and initialize\n\
 its values.  The dimensions of each cell array of values must match.\n\
 Singleton cells and non-cell values are repeated so that they fill\n\
 the entire array.  If the cells are empty, create an empty structure\n\
-array with the specified field names.")
+array with the specified field names.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -678,8 +684,6 @@ the second must be a string.\n\
 
 	  retval = m.contains (key) != 0;
 	}
-      else
-	print_usage ("isfield");
     }
   else
     print_usage ("isfield");
@@ -1084,7 +1088,7 @@ octave_struct::load_binary (std::istream& is, bool swap,
   if (! is.read (X_CAST (char *, &len), 4))
     return false;
   if (swap)
-    swap_4_bytes (X_CAST (char *, &len));
+    swap_bytes<4> (&len);
 
   if (len > 0)
     {
@@ -1168,7 +1172,9 @@ octave_struct::load_hdf5 (hid_t loc_id, const char *name,
   int current_item = 0;
 #ifdef HAVE_H5GGET_NUM_OBJS
   hsize_t num_obj = 0;
-  H5Gget_num_objs (loc_id, &num_obj);
+  hid_t group_id = H5Gopen (loc_id, name); 
+  H5Gget_num_objs (group_id, &num_obj);
+  H5Gclose (group_id);
 
   while (current_item < static_cast<int> (num_obj)
 	 && (retval2 = H5Giterate (loc_id, name, &current_item,
