@@ -69,16 +69,17 @@ public:
 
   Cell dotref (const octave_value_list& idx);
 
-  octave_value subsref (const std::string& type,
-			const std::list<octave_value_list>& idx);
-
-  octave_value_list subsref (const std::string&,
-			     const std::list<octave_value_list>&, int)
+  octave_value subsref (const std::string&,
+			const std::list<octave_value_list>&)
     {
       panic_impossible ();
       return octave_value_list ();
     }
 
+  octave_value_list subsref (const std::string& type,
+			     const std::list<octave_value_list>& idx,
+			     int nargout);
+
   static octave_value numeric_conv (const Cell& val,
 				    const std::string& type);
 
@@ -93,9 +94,10 @@ public:
   octave_value reshape (const dim_vector& new_dims) const
     { return map.reshape (new_dims); }
 
-  bool is_defined (void) const { return true; }
+  octave_value resize (const dim_vector& dv) const
+    { return map.resize (dv); }
 
-  bool is_constant (void) const { return true; }
+  bool is_defined (void) const { return true; }
 
   bool is_map (void) const { return true; }
 
