@@ -79,8 +79,6 @@ octave_user_function::octave_user_function
     curr_va_arg_number (0), vr_list (0), symtab_entry (0),
     argn_sr (0), nargin_sr (0), nargout_sr (0), varargin_sr (0)
 {
-  install_automatic_vars ();
-
   if (param_list)
     {
       num_named_args = param_list->length ();
@@ -320,7 +318,7 @@ octave_user_function::subsref (const std::string& type,
   // octave_builtin::subsref.
 
   if (idx.size () > 1)
-    retval = retval(0).next_subsref (type, idx);
+    retval = retval(0).next_subsref (nargout, type, idx);
 
   return retval;
 }
@@ -339,7 +337,7 @@ octave_user_function::do_multi_index_op (int nargout,
 
   int nargin = args.length ();
 
-  unwind_protect::begin_frame ("func_eval");
+  unwind_protect::begin_frame ("user_func_eval");
 
   unwind_protect_int (call_depth);
   call_depth++;
@@ -347,7 +345,7 @@ octave_user_function::do_multi_index_op (int nargout,
   if (call_depth > Vmax_recursion_depth)
     {
       ::error ("max_recursion_limit exceeded");
-      unwind_protect::run_frame ("func_eval");
+      unwind_protect::run_frame ("user_func_eval");
       return retval;
     }
 
@@ -379,6 +377,8 @@ octave_user_function::do_multi_index_op (int nargout,
   if (vr_list)
     vr_list->clear ();
 
+  install_automatic_vars ();
+
   // Force symbols to be undefined again when this function exits.
 
   unwind_protect::add (clear_symbol_table, sym_tab);
@@ -393,6 +393,11 @@ octave_user_function::do_multi_index_op (int nargout,
   curr_sym_tab = sym_tab;
 
   unwind_protect_ptr (curr_function);
+  unwind_protect_ptr (curr_caller_function);
+  unwind_protect_ptr (curr_caller_statement);
+
+  curr_caller_statement = curr_statement;
+  curr_caller_function = curr_function;
   curr_function = this;
 
   if (! is_nested_function ())
@@ -488,7 +493,7 @@ octave_user_function::do_multi_index_op (int nargout,
   }
 
  abort:
-  unwind_protect::run_frame ("func_eval");
+  unwind_protect::run_frame ("user_func_eval");
 
   return retval;
 }
@@ -606,7 +611,9 @@ function accepts a variable number of arguments.\n\
 
       if (! error_state)
 	{
-	  octave_user_function *fcn = lookup_user_function (fname);
+	  octave_value fcn_val = lookup_user_function (fname);
+
+	  octave_user_function *fcn = fcn_val.user_function_value (true);
 
 	  if (fcn)
 	    {
@@ -676,7 +683,9 @@ At the top level, @code{nargout} is undefined.\n\
 
       if (! error_state)
 	{
-	  octave_user_function *fcn = lookup_user_function (fname);
+	  octave_value fcn_val = lookup_user_function (fname);
+
+	  octave_user_function *fcn = fcn_val.user_function_value (true);
 
 	  if (fcn)
 	    {
