@@ -239,9 +239,9 @@ octave_pager_buf::sync (void)
 	{
 	  do_sync (buf, len, bypass_pager);
 
-	  seekoff (0, std::ios::beg);
-
 	  flush_current_contents_to_diary ();
+
+	  seekoff (0, std::ios::beg);
 	}
     }
 
@@ -257,7 +257,7 @@ octave_pager_buf::flush_current_contents_to_diary (void)
 
   octave_diary.write (buf, len);
 
-  diary_skip = 0;  
+  diary_skip = 0;
 }
 
 void
@@ -271,10 +271,12 @@ octave_diary_buf::sync (void)
 {
   if (write_to_diary_file && external_diary_file)
     {
-      int len = pptr () - eback ();
+      char *buf = eback ();
+
+      int len = pptr () - buf;
 
       if (len > 0)
-	external_diary_file.write (eback (), len);
+	external_diary_file.write (buf, len);
     }
 
   seekoff (0, std::ios::beg);
@@ -286,7 +288,7 @@ octave_pager_stream *octave_pager_stream::instance = 0;
 
 octave_pager_stream::octave_pager_stream (void) : std::ostream (0), pb (0)
 {
-  pb = new octave_pager_buf;
+  pb = new octave_pager_buf ();
   rdbuf (pb);
   setf (unitbuf);
 }
@@ -324,7 +326,7 @@ octave_diary_stream *octave_diary_stream::instance = 0;
 
 octave_diary_stream::octave_diary_stream (void) : std::ostream (0), db (0)
 {
-  db = new octave_diary_buf;
+  db = new octave_diary_buf ();
   rdbuf (db);
   setf (unitbuf);
 }
@@ -405,7 +407,7 @@ open_diary_file (void)
     error ("diary: can't open diary file `%s'", diary_file.c_str ());
 }
 
-DEFUN_TEXT (diary, args, ,
+DEFCMD (diary, args, ,
   "-*- texinfo -*-\n\
 @deffn {Command} diary options\n\
 Create a list of all commands @emph{and} the output they produce, mixed\n\
@@ -476,7 +478,7 @@ Without any arguments, @code{diary} toggles the current diary state.\n\
   return retval;
 }
 
-DEFUN_TEXT (more, args, ,
+DEFCMD (more, args, ,
   "-*- texinfo -*-\n\
 @deffn {Command} more\n\
 @deffnx {Command} more on\n\
@@ -499,12 +501,19 @@ toggles the current state.\n\
       std::string arg = argv[1];
 
       if (arg == "on")
-	bind_builtin_variable ("page_screen_output", 1.0);
+	bind_builtin_variable ("page_screen_output", true);
       else if (arg == "off")
-	bind_builtin_variable ("page_screen_output", 0.0);
+	bind_builtin_variable ("page_screen_output", false);
       else
 	error ("more: unrecognized argument `%s'", arg.c_str ());
     }
+  else if (argc == 1)
+    {
+      octave_value tmp = builtin_any_variable ("page_screen_output");
+
+      if (! error_state)
+	bind_builtin_variable ("page_screen_output", ! tmp.is_true ());
+    }
   else
     print_usage ("more");
 
@@ -585,7 +594,7 @@ terminal that is more than one screen long to the program named by the\n\
 value of the variable @code{PAGER}.\n\
 @end defvr");
 
-  DEFVAR (page_output_immediately, 0.0, page_output_immediately,
+  DEFVAR (page_output_immediately, false, page_output_immediately,
     "-*- texinfo -*-\n\
 @defvr {Built-in Variable} page_output_immediately\n\
 If the value of @code{page_output_immediately} is nonzero, Octave sends\n\
@@ -594,7 +603,7 @@ buffers its output and waits until just before the prompt is printed to\n\
 flush it to the pager.  The default value is 0.\n\
 @end defvr");
 
-  DEFVAR (page_screen_output, 1.0, page_screen_output,
+  DEFVAR (page_screen_output, true, page_screen_output,
     "-*- texinfo -*-\n\
 @defvr {Built-in Variable} page_screen_output\n\
 If the value of @code{page_screen_output} is nonzero, all output\n\
