@@ -27,15 +27,16 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <string>
 
-#include "SLStack.h"
+#include <stack>
 
 extern void reset_parser (void);
-extern int yylex (void);
-extern int yyparse (void);
+extern int octave_lex (void);
+extern int octave_parse (void);
 
 class tree;
 class tree_matrix;
 class tree_identifier;
+class octaev_function;
 class symbol_record;
 class symbol_table;
 
@@ -45,7 +46,7 @@ class symbol_table;
 extern symbol_table *tmp_local_sym_tab;
 
 // Nonzero means print parser debugging info (-d).
-extern int yydebug;
+extern int octave_debug;
 
 // The current input line number.
 extern int input_line_number;
@@ -54,7 +55,7 @@ extern int input_line_number;
 extern int current_input_column;
 
 // Buffer for help text snagged from function files.
-extern std::string help_buf;
+extern std::stack<std::string> help_buf;
 
 // TRUE means we are using readline.
 extern bool line_editing;
@@ -74,9 +75,19 @@ extern bool input_from_command_line_file;
 // an eval() statement.
 extern bool evaluating_function_body;
 
+// Keep track of symbol table information when parsing functions.
+extern std::stack<symbol_table*> symtab_context;
+
+// Name of parent function when parsing function files that might
+// contain nested functions.
+extern std::string parent_function_name;
+
 // TRUE means warn about function files that have time stamps in the future.
 extern bool Vwarn_future_time_stamp;
 
+// Keep a count of how many END tokens we expect.
+extern int end_tokens_expected;
+
 extern void
 parse_and_execute (FILE *f);
 
@@ -89,11 +100,19 @@ extern std::string get_help_from_file (const std::string& f);
 extern bool
 load_fcn_from_file (symbol_record *sym_rec, bool exec_script);
 
+extern void
+source_file (const std::string file_name);
+
 extern octave_value_list
 feval (const std::string& name,
        const octave_value_list& args = octave_value_list (),
        int nargout = 0);
 
+extern octave_value_list
+feval (octave_function *fcn,
+       const octave_value_list& args = octave_value_list (),
+       int nargout = 0);
+
 extern octave_value_list
 feval (const octave_value_list& args, int nargout = 0);
 
