@@ -23,7 +23,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_tree_bp_h)
 #define octave_tree_bp_h 1
 
-#if defined (__GNUG__)
+#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
 #pragma interface
 #endif
 
@@ -89,8 +89,6 @@ tree_breakpoint : public tree_walker
 
   void visit_index_expression (tree_index_expression&);
 
-  void visit_indirect_ref (tree_indirect_ref&);
-
   void visit_matrix (tree_matrix&);
 
   void visit_cell (tree_cell&);
@@ -101,6 +99,8 @@ tree_breakpoint : public tree_walker
 
   void visit_constant (tree_constant&);
 
+  void visit_fcn_handle (tree_fcn_handle&);
+
   void visit_parameter_list (tree_parameter_list&);
 
   void visit_plot_command (tree_plot_command&);
@@ -170,19 +170,26 @@ tree_breakpoint : public tree_walker
   tree_breakpoint& operator = (const tree_breakpoint&);
 };
 
+// TRUE means SIGINT should put us in the debugger at the next
+// available breakpoint.
+extern bool octave_debug_on_interrupt_state;
+
 #define MAYBE_DO_BREAKPOINT \
   do \
     { \
-      if ((tree::break_next && tree::last_line == 0) \
+      if (octave_debug_on_interrupt_state \
+	  || (tree::break_next && tree::last_line == 0) \
 	  || (tree::break_next \
 	      && curr_function == tree::break_function \
 	      && tree::last_line != line ()) \
 	  || is_breakpoint ()) \
         { \
+          octave_debug_on_interrupt_state = false; \
+ \
           tree::break_next = false; \
  \
           if (curr_function) \
-            octave_stdout << curr_function->function_name () << ": ";  \
+            octave_stdout << curr_function->name () << ": ";  \
  \
           octave_stdout << "line " << line () << ", " \
 			<< "column " << column () \
