@@ -59,6 +59,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "pt-walk.h"
 #include "sighandlers.h"
 #include "sysdep.h"
+#include "unwind-prot.h"
 #include "utils.h"
 #include "variables.h"
 
@@ -216,7 +217,11 @@ send_to_plot_stream (const std::string& cmd)
     {
       *plot_stream << cmd;
 
-      if (! (is_replot || is_splot || is_plot)
+      octave_value mm = get_global_value ("__multiplot_mode__", true);
+
+      bool is_multiplot_mode = mm.is_true ();
+
+      if (! (is_replot || is_splot || is_plot || is_multiplot_mode)
 	  && plot_line_count > 0
 	  && Vautomatic_replot)
 	*plot_stream << Vgnuplot_command_replot << Vgnuplot_command_end;
@@ -726,9 +731,6 @@ subplot::handle_plot_data (int ndim, OSSTREAM& plot_buf)
 	    }
 	  else
 	    {
-	      // Eliminate the need for printing a using clause to
-	      // plot_buf.
-
 	      octave_value tmp_data = extract_plot_data (ndim, data);
 
 	      if (tmp_data.is_defined ())
@@ -752,7 +754,13 @@ subplot::handle_plot_data (int ndim, OSSTREAM& plot_buf)
 		  if (file.length () > 0)
 		    {
 		      mark_for_deletion (file);
-		      plot_buf << " '" << file << "'";
+
+		      // Include the using clause so that plotting
+		      // with timefmt will work.
+
+		      plot_buf << " '" << file << "' "
+			       << Vgnuplot_command_using
+			       << (ndim == 2 ? " 1:2" : " 1:2:3");
 		    }
 		}
 	    }
@@ -942,7 +950,13 @@ and clear all the visible variables.)\n\
 @end deftypefn")
 {
   octave_value_list retval;
-  send_to_plot_stream ("clear\n");
+
+  // We are clearing the plot window, so there is no need to redisplay
+  // after each incremental change to the title, labels, etc.
+
+  unwind_protect_bool (Vautomatic_replot);
+
+  Vautomatic_replot = false;
 
   // XXX FIXME XXX -- instead of just clearing these things, it would
   // be nice if we could reset things to a user-specified default
@@ -954,11 +968,17 @@ and clear all the visible variables.)\n\
   send_to_plot_stream ("set nogrid\n");
   send_to_plot_stream ("set nolabel\n");
 
-  // This makes a simple `replot' not work after a `clearplot' command
-  // has been issued.
+  // Clear the plot display last.
+
+  send_to_plot_stream ("clear\n");
+
+  // Setting plot_line_count to zero makes a simple `replot' not work
+  // after a `clearplot' command has been issued.
 
   plot_line_count = 0;
 
+  unwind_protect::run ();
+
   return retval;
 }
 
@@ -1345,7 +1365,7 @@ is @code{\"gnuplot\"}.  @xref{Installation}.\n\
 @defvr {Built-in Variable} gnuplot_has_frames\n\
 If the value of this variable is nonzero, Octave assumes that your copy\n\
 of gnuplot has support for multiple frames that is included in recent\n\
-3.6beta releases.  It's initial value is determined by configure, but it\n\
+3.6beta releases.  Its initial value is determined by configure, but it\n\
 can be changed in your startup script or at the command line in case\n\
 configure got it wrong, or if you upgrade your gnuplot installation.\n\
 @end defvr");
