@@ -23,17 +23,16 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_tree_select_h)
 #define octave_tree_select_h 1
 
-#if defined (__GNUG__)
+#if defined (__GNUG__) && defined (USE_PRAGMA_INTERFACE_IMPLEMENTATION)
 #pragma interface
 #endif
 
-#include <SLList.h>
-
 class expression;
 class tree_statement_list;
 
 class tree_walker;
 
+#include "base-list.h"
 #include "comment-list.h"
 #include "pt-cmd.h"
 
@@ -88,22 +87,21 @@ private:
 };
 
 class
-tree_if_command_list : public SLList<tree_if_clause *>
+tree_if_command_list : public octave_base_list<tree_if_clause *>
 {
 public:
 
-  tree_if_command_list (void)
-    : SLList<tree_if_clause *> () { }
+  tree_if_command_list (void) { }
 
-  tree_if_command_list (tree_if_clause *t)
-    : SLList<tree_if_clause *> () { append (t); }
+  tree_if_command_list (tree_if_clause *t) { append (t); }
 
   ~tree_if_command_list (void)
     {
       while (! empty ())
 	{
-	  tree_if_clause *t = remove_front ();
-	  delete t;
+	  iterator p = begin ();
+	  delete *p;
+	  erase (p);
 	}
     }
 
@@ -181,8 +179,7 @@ public:
 
   ~tree_switch_case (void);
 
-  bool is_default_case (void)
-    { return ! label; }
+  bool is_default_case (void) { return ! label; }
 
   bool label_matches (const octave_value& val);
 
@@ -217,22 +214,21 @@ private:
 };
 
 class
-tree_switch_case_list : public SLList<tree_switch_case *>
+tree_switch_case_list : public octave_base_list<tree_switch_case *>
 {
 public:
 
-  tree_switch_case_list (void)
-    : SLList<tree_switch_case *> () { }
+  tree_switch_case_list (void) { }
 
-  tree_switch_case_list (tree_switch_case *t)
-    : SLList<tree_switch_case *> () { append (t); }
+  tree_switch_case_list (tree_switch_case *t) { append (t); }
 
   ~tree_switch_case_list (void)
     {
       while (! empty ())
 	{
-	  tree_switch_case *t = remove_front ();
-	  delete t;
+	  iterator p = begin ();
+	  delete *p;
+	  erase (p);
 	}
     }
 
