@@ -37,11 +37,16 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 
 #include "cmd-edit.h"
+#include "quit.h"
 
+#include "defun.h"
 #include "error.h"
 #include "load-save.h"
+#include "oct-map.h"
 #include "pager.h"
+#include "pt-bp.h"
 #include "sighandlers.h"
+#include "sysdep.h"
 #include "syswait.h"
 #include "toplev.h"
 #include "utils.h"
@@ -53,17 +58,16 @@ int pipe_handler_error_count = 0;
 // TRUE means we can be interrupted.
 bool can_interrupt = false;
 
-// Allow us to save the signal mask and then restore it to the most
-// recently saved value.  This is necessary when using the POSIX
-// signal handling interface on some systems calling longjmp out of
-// the signal handler to get to the top level on an interrupt doesn't
-// restore the original signal mask.  Alternatively, we could use
-// sigsetjmp/siglongjmp, but saving and restoring the signal mask
-// ourselves works ok and seems simpler just now.
+// TRUE means we should try to enter the debugger on SIGINT.
+static bool Vdebug_on_interrupt = false;
 
-#if defined (HAVE_POSIX_SIGNALS)
-static sigset_t octave_signal_mask;
-#endif
+// Allow users to avoid writing octave-core for SIGHUP (sent by
+// closing gnome-terminal, for example).  Note that this variable has
+// no effect if Vcrash_dumps_octave_core is FALSE.
+static bool Vsighup_dumps_octave_core;
+
+// Similar to Vsighup_dumps_octave_core, but for SIGTERM signal.
+static bool Vsigterm_dumps_octave_core;
 
 #if RETSIGTYPE == void
 #define SIGHANDLER_RETURN(status) return
@@ -89,30 +93,9 @@ static sigset_t octave_signal_mask;
   do { } while (0)
 #endif
 
-#if defined (SIGABRT)
-#define OCTAVE_MEMORY_EXHAUSTED_ERROR SIGABRT
-#else
-#define OCTAVE_MEMORY_EXHAUSTED_ERROR (-1)
-#endif
-
-void
-octave_save_signal_mask (void)
-{
-#if defined (HAVE_POSIX_SIGNALS)
-  sigprocmask (0, 0, &octave_signal_mask);
-#endif
-}
-
-void
-octave_restore_signal_mask (void)
-{
-#if defined (HAVE_POSIX_SIGNALS)
-  sigprocmask (SIG_SETMASK, &octave_signal_mask, 0);
-#endif
-}
-
 static void
-my_friendly_exit (const char *sig_name, int sig_number)
+my_friendly_exit (const char *sig_name, int sig_number,
+		  bool save_vars = true)
 {
   static bool been_there_done_that = false;
 
@@ -131,7 +114,8 @@ my_friendly_exit (const char *sig_name, int sig_number)
 
       std::cerr << "panic: " << sig_name << " -- stopping myself...\n";
 
-      save_user_variables ();
+      if (save_vars)
+	dump_octave_core ();
 
       if (sig_number < 0)
 	exit (1);
@@ -139,27 +123,18 @@ my_friendly_exit (const char *sig_name, int sig_number)
 	{
 	  octave_set_signal_handler (sig_number, SIG_DFL);
 
+#if defined (HAVE_RAISE)
+	  raise (sig_number);
+#elif defined (HAVE_KILL)
 	  kill (getpid (), sig_number);
+#else
+	  exit (1);
+#endif
 	}
+
     }
 }
 
-// I know, not really a signal handler.
-
-static void
-octave_new_handler (void)
-{
-  std::cerr << "error: memory exhausted -- trying to return to prompt\n";
-
-  if (can_interrupt)
-    {
-      jump_to_top_level ();
-      panic_impossible ();
-    }
-  else
-    my_friendly_exit ("operator new", OCTAVE_MEMORY_EXHAUSTED_ERROR);
-}
-
 sig_handler *
 octave_set_signal_handler (int sig, sig_handler *handler)
 {
@@ -186,6 +161,7 @@ generic_sig_handler (int sig)
 
 // Handle SIGCHLD.
 
+#ifdef SIGCHLD
 static RETSIGTYPE
 sigchld_handler (int /* sig */)
 {
@@ -245,7 +221,9 @@ sigchld_handler (int /* sig */)
 
   SIGHANDLER_RETURN (0);
 }
+#endif /* defined(SIGCHLD) */
 
+#ifdef SIGFPE
 #if defined (__alpha__)
 static RETSIGTYPE
 sigfpe_handler (int /* sig */)
@@ -256,12 +234,51 @@ sigfpe_handler (int /* sig */)
 
   std::cerr << "error: floating point exception -- trying to return to prompt\n";
 
-  if (can_interrupt)
+  // XXX FIXME XXX -- will setting octave_interrupt_state really help
+  // here?
+
+  if (can_interrupt && octave_interrupt_state >= 0)
+    octave_interrupt_state++;
+
+  SIGHANDLER_RETURN (0);
+}
+#endif /* defined(__alpha__) */
+#endif /* defined(SIGFPE) */
+
+#if defined (SIGHUP) || defined (SIGTERM)
+static RETSIGTYPE
+sig_hup_or_term_handler (int sig)
+{
+  MAYBE_ACK_SIGNAL (sig);
+
+  MAYBE_REINSTALL_SIGHANDLER (sig, sig_hup_or_term_handler);
+
+  switch (sig)
     {
-      jump_to_top_level ();
-      panic_impossible ();
+#if defined (SIGHUP)
+    case SIGHUP:
+      {
+	if (Vsighup_dumps_octave_core)
+	  dump_octave_core ();
+      }
+      break;
+#endif
+
+#if defined (SIGTERM)
+    case SIGTERM:
+      {
+	if (Vsigterm_dumps_octave_core)
+	  dump_octave_core ();
+      }
+      break;
+#endif
+
+    default:
+      break;
     }
 
+  clean_up_and_exit (0);
+
   SIGHANDLER_RETURN (0);
 }
 #endif
@@ -289,25 +306,55 @@ sigwinch_handler (int /* sig */)
 // for SIGINT only.
 
 static RETSIGTYPE
-#if defined (ACK_USES_SIG) || defined (REINSTALL_USES_SIG)
 sigint_handler (int sig)
-#else
-sigint_handler (int)
-#endif
 {
   MAYBE_ACK_SIGNAL (sig);
 
   MAYBE_REINSTALL_SIGHANDLER (sig, sigint_handler);
 
+  if (! octave_initialized)
+    exit (1);
+
   if (can_interrupt)
     {
-      jump_to_top_level ();
-      panic_impossible ();
+      if (Vdebug_on_interrupt)
+	{
+	  if (! octave_debug_on_interrupt_state)
+	    {
+	      octave_debug_on_interrupt_state = true;
+
+	      SIGHANDLER_RETURN (0);
+	    }
+	  else
+	    // Clear the flag and do normal interrupt stuff.
+	    octave_debug_on_interrupt_state = false;
+	}
+
+      if (octave_interrupt_immediately)
+	octave_jump_to_enclosing_context ();
+      else
+	{
+	  // If we are already cleaning up from a previous interrupt,
+	  // take note of the fact that another interrupt signal has
+	  // arrived.
+
+	  if (octave_interrupt_state < 0)
+	    octave_interrupt_state = 0;
+
+	  octave_interrupt_state++;
+
+	  if (interactive && octave_interrupt_state == 2)
+	    std::cerr << "Press Control-C again to abort." << std::endl;
+
+	  if (octave_interrupt_state >= 3)
+	    my_friendly_exit (sys_siglist[sig], sig, true);
+	}
     }
 
   SIGHANDLER_RETURN (0);
 }
 
+#ifdef SIGPIPE
 static RETSIGTYPE
 sigpipe_handler (int /* sig */)
 {
@@ -320,11 +367,15 @@ sigpipe_handler (int /* sig */)
 
   // Don't loop forever on account of this.
 
-  if (pipe_handler_error_count  > 100)
-    jump_to_top_level ();
+  // XXX FIXME XXX -- will setting octave_interrupt_state really help
+  // here?
+
+  if (pipe_handler_error_count  > 100 && octave_interrupt_state >= 0)
+    octave_interrupt_state++;
 
   SIGHANDLER_RETURN (0);
 }
+#endif /* defined(SIGPIPE) */
 
 octave_interrupt_handler
 octave_catch_interrupts (void)
@@ -379,8 +430,6 @@ octave_set_interrupt_handler (const volatile octave_interrupt_handler& h)
 void
 install_signal_handlers (void)
 {
-  std::set_new_handler (octave_new_handler);
-
   octave_catch_interrupts ();
 
 #ifdef SIGABRT
@@ -415,7 +464,7 @@ install_signal_handlers (void)
 #endif
 
 #ifdef SIGHUP
-  octave_set_signal_handler (SIGHUP, generic_sig_handler);
+  octave_set_signal_handler (SIGHUP, sig_hup_or_term_handler);
 #endif
 
 #ifdef SIGILL
@@ -462,7 +511,7 @@ install_signal_handlers (void)
 #endif
 
 #ifdef SIGTERM
-  octave_set_signal_handler (SIGTERM, generic_sig_handler);
+  octave_set_signal_handler (SIGTERM, sig_hup_or_term_handler);
 #endif
 
 #ifdef SIGTRAP
@@ -505,6 +554,154 @@ install_signal_handlers (void)
 #endif
 }
 
+static Octave_map
+make_sig_struct (void)
+{
+  Octave_map m;
+
+#ifdef SIGABRT
+  m.assign ("ABRT", SIGABRT);
+#endif
+
+#ifdef SIGALRM
+  m.assign ("ALRM", SIGALRM);
+#endif
+
+#ifdef SIGBUS
+  m.assign ("BUS", SIGBUS);
+#endif
+
+#ifdef SIGCHLD
+  m.assign ("CHLD", SIGCHLD);
+#endif
+
+#ifdef SIGCLD
+  m.assign ("CLD", SIGCLD);
+#endif
+
+#ifdef SIGCONT
+  m.assign ("CONT", SIGCONT);
+#endif
+
+#ifdef SIGEMT
+  m.assign ("EMT", SIGEMT);
+#endif
+
+#ifdef SIGFPE
+  m.assign ("FPE", SIGFPE);
+#endif
+
+#ifdef SIGHUP
+  m.assign ("HUP", SIGHUP);
+#endif
+
+#ifdef SIGILL
+  m.assign ("ILL", SIGILL);
+#endif
+
+#ifdef SIGINFO
+  m.assign ("INFO", SIGINFO);
+#endif
+
+#ifdef SIGINT
+  m.assign ("INT", SIGINT);
+#endif
+
+#ifdef SIGIOT
+  m.assign ("IOT", SIGIOT);
+#endif
+
+#ifdef SIGLOST
+  m.assign ("LOST", SIGLOST);
+#endif
+
+#ifdef SIGPIPE
+  m.assign ("PIPE", SIGPIPE);
+#endif
+
+#ifdef SIGPOLL
+  m.assign ("POLL", SIGPOLL);
+#endif
+
+#ifdef SIGPROF
+  m.assign ("PROF", SIGPROF);
+#endif
+
+#ifdef SIGPWR
+  m.assign ("PWR", SIGPWR);
+#endif
+
+#ifdef SIGQUIT
+  m.assign ("QUIT", SIGQUIT);
+#endif
+
+#ifdef SIGSEGV
+  m.assign ("SEGV", SIGSEGV);
+#endif
+
+#ifdef SIGSTOP
+  m.assign ("STOP", SIGSTOP);
+#endif
+
+#ifdef SIGSYS
+  m.assign ("SYS", SIGSYS);
+#endif
+
+#ifdef SIGTERM
+  m.assign ("TERM", SIGTERM);
+#endif
+
+#ifdef SIGTRAP
+  m.assign ("TRAP", SIGTRAP);
+#endif
+
+#ifdef SIGTSTP
+  m.assign ("TSTP", SIGTSTP);
+#endif
+
+#ifdef SIGTTIN
+  m.assign ("TTIN", SIGTTIN);
+#endif
+
+#ifdef SIGTTOU
+  m.assign ("TTOU", SIGTTOU);
+#endif
+
+#ifdef SIGURG
+  m.assign ("URG", SIGURG);
+#endif
+
+#ifdef SIGUSR1
+  m.assign ("USR1", SIGUSR1);
+#endif
+
+#ifdef SIGUSR2
+  m.assign ("USR2", SIGUSR2);
+#endif
+
+#ifdef SIGVTALRM
+  m.assign ("VTALRM", SIGVTALRM);
+#endif
+
+#ifdef SIGIO
+  m.assign ("IO", SIGIO);
+#endif
+
+#ifdef SIGWINCH
+  m.assign ("WINCH", SIGWINCH);
+#endif
+
+#ifdef SIGXCPU
+  m.assign ("XCPU", SIGXCPU);
+#endif
+
+#ifdef SIGXFSZ
+  m.assign ("XFSZ", SIGXFSZ);
+#endif
+
+  return m;
+}
+
 octave_child_list *octave_child_list::instance = 0;
 
 bool
@@ -626,6 +823,68 @@ octave_child_list::do_elem (int i)
     return foo;
 }
 
+static int
+debug_on_interrupt (void)
+{
+  Vdebug_on_interrupt = check_preference ("debug_on_interrupt");
+
+  return 0;
+}
+
+static int
+sighup_dumps_octave_core (void)
+{
+  Vsighup_dumps_octave_core = check_preference ("sighup_dumps_octave_core");
+
+  return 0;
+}
+
+static int
+sigterm_dumps_octave_core (void)
+{
+  Vsigterm_dumps_octave_core = check_preference ("sigterm_dumps_octave_core");
+
+  return 0;
+}
+
+void
+symbols_of_sighandlers (void)
+{
+  DEFVAR (debug_on_interrupt, false, debug_on_interrupt,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} debug_on_interrupt\n\
+If @code{debug_on_interrupt} is nonzero, Octave will try to enter\n\
+debugging mode when it receives an interrupt signal (typically\n\
+generated with @kbd{C-c}).  If a second interrupt signal is received\n\
+before reaching the debugging mode, a normal interrupt will occur.\n\
+The default value is 0.\n\
+@end defvr");
+
+  DEFVAR (sighup_dumps_octave_core, true, sighup_dumps_octave_core,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} sighup_dumps_octave_core\n\
+If this variable is set to a nonzero value and\n\
+@code{crash_dumps_octave_core} is also nonzero, Octave tries to save all\n\
+current variables the the file \"octave-core\" if it receives a\n\
+hangup signal.  The default value is 1.\n\
+@end defvr");
+
+  DEFVAR (sigterm_dumps_octave_core, true, sigterm_dumps_octave_core,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} sigterm_dumps_octave_core\n\
+If this variable is set to a nonzero value and\n\
+@code{crash_dumps_octave_core} is also nonzero, Octave tries to save all\n\
+current variables the the file \"octave-core\" if it receives a\n\
+terminate signal.  The default value is 1.\n\
+@end defvr");
+
+  DEFCONST (SIG, make_sig_struct (),
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} SIG\n\
+Structure of Unix signal names and their defined values.\n\
+@end defvr");
+}
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
