@@ -93,6 +93,9 @@ tree_statement_list *global_command = 0;
 // Pointer to function that is currently being evaluated.
 octave_function *curr_function = 0;
 
+// Pointer to caller of curr_function.
+octave_function *curr_caller_function = 0;
+
 // Pointer to parent function that is currently being evaluated.
 octave_function *curr_parent_function = 0;
 
