@@ -662,6 +662,30 @@ symbol_exist (const std::string& name, const std::string& type)
   return retval;
 }
 
+#define GET_IDX(LEN) \
+  static_cast<int> ((LEN-1) * static_cast<double> (rand ()) / RAND_MAX)
+
+std::string
+unique_symbol_name (const std::string& basename)
+{
+  static const std::string alpha
+    = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
+
+  static size_t len = alpha.length ();
+
+  std::string nm = basename + alpha[GET_IDX (len)];
+
+  size_t pos = nm.length ();
+
+  if (nm.substr (0, 2) == "__")
+    nm.append ("__");
+
+  while (symbol_exist (nm, "any"))
+    nm.insert (pos++, 1, alpha[GET_IDX (len)]);
+
+  return nm;
+}
+
 DEFUN (exist, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} exist (@var{name}, @var{type})\n\
@@ -748,19 +772,28 @@ symbol_out_of_date (symbol_record *sr)
 		{
 		  time_t tp = tmp->time_parsed ();
 
-		  std::string fname;
+		  std::string nm = tmp->name ();
 
-		  if (tmp->is_dld_function ())
-		    fname = ff;
-		  else
-		    fname = fcn_file_in_path (ff);
+		  string_vector names (2);
 
-		  tmp->mark_fcn_file_up_to_date (octave_time ());
+		  names[0] = nm + ".oct";
+		  names[1] = nm + ".m";
 
-		  file_stat fs (fname);
+		  std::string file = octave_env::make_absolute
+		    (Vload_path_dir_path.find_first_of (names),
+		     octave_env::getcwd ());
 
-		  if (fs && fs.is_newer (tp))
+		  if (file != ff)
 		    retval = true;
+		  else
+		    {
+		      tmp->mark_fcn_file_up_to_date (octave_time ());
+
+		      file_stat fs (ff);
+
+		      if (fs && fs.is_newer (tp))
+			retval = true;
+		    }
 		}
 	    }
 	}
@@ -811,10 +844,10 @@ lookup_by_name (const std::string& nm, bool exec_script)
   return sym_rec;
 }
 
-octave_function *
+octave_value
 lookup_function (const std::string& nm)
 {
-  octave_function *retval = 0;
+  octave_value retval;
 
   symbol_record *sr = 0;
 
@@ -838,16 +871,16 @@ lookup_function (const std::string& nm)
       octave_value v = sr->def ();
 
       if (v.is_function ())
-	retval = v.function_value ();
+	retval = v;
     }
 
   return retval;
 }
 
-octave_user_function *
+octave_value
 lookup_user_function (const std::string& nm)
 {
-  octave_user_function *retval = 0;
+  octave_value retval;
 
   symbol_record *sr = 0;
 
@@ -867,17 +900,26 @@ lookup_user_function (const std::string& nm)
     }
 
   if (sr)
-    {
-      octave_value v = sr->def ();
-
-      retval = v.user_function_value (true);
-    }
+    retval = sr->def ();
 
   return retval;
 }
 
 octave_value
-get_global_value (const std::string& nm)
+lookup_function_handle (const std::string& nm)
+{
+  octave_value retval;
+
+  symbol_record *sr = curr_sym_tab->lookup (nm, true);
+
+  if (sr && sr->def ().is_function_handle ())
+    retval = sr->def ();
+
+  return retval;
+}
+
+octave_value
+get_global_value (const std::string& nm, bool silent)
 {
   octave_value retval;
 
@@ -887,12 +929,12 @@ get_global_value (const std::string& nm)
     {
       octave_value sr_def = sr->def ();
 
-      if (sr_def.is_undefined ())
-	error ("get_global_by_name: undefined symbol `%s'", nm.c_str ());
-      else
+      if (sr_def.is_defined ())
 	retval = sr_def;
+      else if (! silent)
+	error ("get_global_by_name: undefined symbol `%s'", nm.c_str ());
     }
-  else
+  else if (! silent)
     error ("get_global_by_name: unknown symbol `%s'", nm.c_str ());
 
   return retval;
@@ -1212,7 +1254,7 @@ do_who (int argc, const string_vector& argv, int return_list)
 
 	  octave_value_list ovl (len, octave_value ());
 
-	  for (int j = 0; j < len; i++)
+	  for (int j = 0; j < len; j++)
 	    ovl(j) = names(j);
 
 	  retval = Octave_map ("name", ovl);
@@ -1901,6 +1943,24 @@ do_matlab_compatible_clear (const string_vector& argv, int argc, int idx)
     } \
   while (0)
 
+bool
+clear_function (const std::string& nm)
+{
+  return do_clear_function (nm);
+}
+
+bool
+clear_variable (const std::string& nm)
+{
+  return do_clear_variable (nm);
+}
+
+bool
+clear_symbol (const std::string& nm)
+{
+  return do_clear_symbol (nm);
+}
+
 DEFCMD (clear, args, ,
   "-*- texinfo -*-\n\
 @deffn {Command} clear [-x] pattern @dots{}\n\
