@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 1998 John W. Eaton
+Copyright (C) 1996-2004 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,9 +23,9 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_version_h)
 #define octave_version_h 1
 
-#define OCTAVE_VERSION "2.1.57"
+#define OCTAVE_VERSION "2.1.64"
 
-#define OCTAVE_API_VERSION "api-v8"
+#define OCTAVE_API_VERSION "api-v12"
 
 #define OCTAVE_COPYRIGHT \
   "Copyright (C) 2004 John W. Eaton."
@@ -48,7 +48,7 @@ FITNESS FOR A PARTICULAR PURPOSE."
 For more information, visit http://www.octave.org/help-wanted.html"
 
 #define OCTAVE_BUGS_STATEMENT \
-  "Report bugs to <bug-octave@bevo.che.wisc.edu> (but first, please read\n\
+  "Report bugs to <bug@octave.org> (but first, please read\n\
 http://www.octave.org/bugs.html to learn how to write a helpful report)."
 
 #define OCTAVE_NAME_VERSION_AND_COPYRIGHT \
