@@ -27,6 +27,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <cassert>
 #include <climits>
 
+#include "Array-util.h"
 #include "CColVector.h"
 #include "CDiagMatrix.h"
 #include "CMatrix.h"
@@ -35,9 +36,10 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "dMatrix.h"
 #include "mx-cm-cdm.h"
 #include "oct-cmplx.h"
+#include "quit.h"
 
 #include "error.h"
-#include "ov.h"
+#include "oct-obj.h"
 #include "utils.h"
 #include "xpow.h"
 
@@ -68,8 +70,13 @@ xpow (double a, double b)
 {
   if (a < 0.0 && static_cast<int> (b) != b)
     {
+      // XXX FIXME XXX -- avoid apparent GNU libm bug by converting
+      // A and B to complex instead of just A.
+
       Complex atmp (a);
-      return pow (atmp, b);
+      Complex btmp (b);
+
+      return pow (atmp, btmp);
     }
   else
     return pow (a, b);
@@ -500,7 +507,10 @@ elem_xpow (double a, const Matrix& b)
       ComplexMatrix result (nr, nc);
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (atmp, b (i, j));
+	  {
+	    OCTAVE_QUIT;
+	    result (i, j) = pow (atmp, b (i, j));
+	  }
 
       retval = result;
     }
@@ -509,7 +519,10 @@ elem_xpow (double a, const Matrix& b)
       Matrix result (nr, nc);
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (a, b (i, j)); 
+	  {
+	    OCTAVE_QUIT;
+	    result (i, j) = pow (a, b (i, j));
+	  }
 
       retval = result;
     }
@@ -528,7 +541,10 @@ elem_xpow (double a, const ComplexMatrix& b)
   Complex atmp (a);
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
-      result (i, j) = pow (atmp, b (i, j));
+      {
+	OCTAVE_QUIT;
+	result (i, j) = pow (atmp, b (i, j));
+      }
 
   return result;
 }
@@ -548,8 +564,15 @@ elem_xpow (const Matrix& a, double b)
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
 	  {
+	    OCTAVE_QUIT;
+      
+	    // XXX FIXME XXX -- avoid apparent GNU libm bug by
+	    // converting A and B to complex instead of just A.
+
 	    Complex atmp (a (i, j));
-	    result (i, j) = pow (atmp, b);
+	    Complex btmp (b);
+
+	    result (i, j) = pow (atmp, btmp);
 	  }
 
       retval = result;
@@ -559,7 +582,10 @@ elem_xpow (const Matrix& a, double b)
       Matrix result (nr, nc);
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (a (i, j), b);
+	  {
+	    OCTAVE_QUIT;
+	    result (i, j) = pow (a (i, j), b);
+	  }
 
       retval = result;
     }
@@ -589,6 +615,7 @@ elem_xpow (const Matrix& a, const Matrix& b)
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
       {
+	OCTAVE_QUIT;
 	double atmp = a (i, j);
 	double btmp = b (i, j);
 	if (atmp < 0.0 && static_cast<int> (btmp) != btmp)
@@ -607,6 +634,7 @@ done:
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
 	  {
+	    OCTAVE_QUIT;
 	    Complex atmp (a (i, j));
 	    Complex btmp (b (i, j));
 	    complex_result (i, j) = pow (atmp, btmp);
@@ -620,7 +648,10 @@ done:
 
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (a (i, j), b (i, j));
+	  {
+	    OCTAVE_QUIT;
+	    result (i, j) = pow (a (i, j), b (i, j));
+	  }
 
       retval = result;
     }
@@ -638,7 +669,10 @@ elem_xpow (const Matrix& a, const Complex& b)
   ComplexMatrix result (nr, nc);
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
-      result (i, j) = pow (Complex (a (i, j)), b);
+      {
+	OCTAVE_QUIT;
+	result (i, j) = pow (Complex (a (i, j)), b);
+      }
 
   return result;
 }
@@ -662,7 +696,10 @@ elem_xpow (const Matrix& a, const ComplexMatrix& b)
   ComplexMatrix result (nr, nc);
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
-      result (i, j) = pow (Complex (a (i, j)), b (i, j));
+      {
+	OCTAVE_QUIT;
+	result (i, j) = pow (Complex (a (i, j)), b (i, j));
+      }
 
   return result;
 }
@@ -678,6 +715,7 @@ elem_xpow (const Complex& a, const Matrix& b)
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
       {
+	OCTAVE_QUIT;
 	double btmp = b (i, j);
 	if (xisint (btmp))
 	  result (i, j) = pow (a, static_cast<int> (btmp));
@@ -698,7 +736,10 @@ elem_xpow (const Complex& a, const ComplexMatrix& b)
   ComplexMatrix result (nr, nc);
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
-      result (i, j) = pow (a, b (i, j));
+      {
+	OCTAVE_QUIT;
+	result (i, j) = pow (a, b (i, j));
+      }
 
   return result;
 }
@@ -716,13 +757,19 @@ elem_xpow (const ComplexMatrix& a, double b)
     {
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (a (i, j), static_cast<int> (b));
+	  {
+	    OCTAVE_QUIT;
+	    result (i, j) = pow (a (i, j), static_cast<int> (b));
+	  }
     }
   else
     {
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (a (i, j), b);
+	  {
+	    OCTAVE_QUIT;
+	    result (i, j) = pow (a (i, j), b);
+	  }
     }
 
   return result;
@@ -748,6 +795,7 @@ elem_xpow (const ComplexMatrix& a, const Matrix& b)
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
       {
+	OCTAVE_QUIT;
 	double btmp = b (i, j);
 	if (xisint (btmp))
 	  result (i, j) = pow (a (i, j), static_cast<int> (btmp));
@@ -768,7 +816,10 @@ elem_xpow (const ComplexMatrix& a, const Complex& b)
   ComplexMatrix result (nr, nc);
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
-      result (i, j) = pow (a (i, j), b);
+      {
+	OCTAVE_QUIT;
+	result (i, j) = pow (a (i, j), b);
+      }
 
   return result;
 }
@@ -792,7 +843,353 @@ elem_xpow (const ComplexMatrix& a, const ComplexMatrix& b)
   ComplexMatrix result (nr, nc);
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
-      result (i, j) = pow (a (i, j), b (i, j));
+      {
+	OCTAVE_QUIT;
+	result (i, j) = pow (a (i, j), b (i, j));
+      }
+
+  return result;
+}
+
+// Safer pow functions that work elementwise for N-d arrays.
+//
+//       op2 \ op1:   s   nd  cs   cnd
+//            +--   +---+---+----+----+
+//   scalar   |     | * | 3 |  * |  9 |
+//                  +---+---+----+----+
+//   N_d            | 1 | 4 |  7 | 10 |
+//                  +---+---+----+----+
+//   complex_scalar | * | 5 |  * | 11 |
+//                  +---+---+----+----+
+//   complex_N_d    | 2 | 6 |  8 | 12 |
+//                  +---+---+----+----+
+//
+//   * -> not needed.
+
+// XXX FIXME XXX -- these functions need to be fixed so that things
+// like
+//
+//   a = -1; b = [ 0, 0.5, 1 ]; r = a .^ b
+//
+// and
+//
+//   a = -1; b = [ 0, 0.5, 1 ]; for i = 1:3, r(i) = a .^ b(i), end
+//
+// produce identical results.  Also, it would be nice if -1^0.5
+// produced a pure imaginary result instead of a complex number with a
+// small real part.  But perhaps that's really a problem with the math
+// library...
+
+// -*- 1 -*-
+octave_value
+elem_xpow (double a, const NDArray& b)
+{
+  octave_value retval;
+
+  double d1, d2;
+
+  if (a < 0.0 && ! b.all_integers (d1, d2))
+    {
+      Complex atmp (a);
+      ComplexNDArray result (b.dims ());
+      for (int i = 0; i < b.length (); i++)
+	{
+	  OCTAVE_QUIT;
+	  result(i) = pow (atmp, b(i));
+	}
+
+      retval = result;
+    }
+  else
+    {
+      NDArray result (b.dims ());
+      for (int i = 0; i < b.length (); i++)
+	{
+	  OCTAVE_QUIT;
+	  result (i) = pow (a, b(i));
+	}
+
+      retval = result;
+    }
+
+  return retval;
+}
+
+// -*- 2 -*-
+octave_value
+elem_xpow (double a, const ComplexNDArray& b)
+{
+  ComplexNDArray result (b.dims ());
+  Complex atmp (a);
+  for (int i = 0; i < b.length (); i++)
+    {
+      OCTAVE_QUIT;
+      result(i) = pow (atmp, b(i));
+    }
+
+  return result;
+}
+
+// -*- 3 -*-
+octave_value
+elem_xpow (const NDArray& a, double b)
+{
+  octave_value retval;
+
+  if (static_cast<int> (b) != b && a.any_element_is_negative ())
+    {
+      ComplexNDArray result (a.dims ());
+
+      for (int i = 0; i < a.length (); i++)
+	{
+	  OCTAVE_QUIT;
+
+	  // XXX FIXME XXX -- avoid apparent GNU libm bug by
+	  // converting A and B to complex instead of just A.
+
+	  Complex atmp (a (i));
+	  Complex btmp (b);
+
+	  result(i) = pow (atmp, btmp);
+	}
+
+      retval = result;
+    }
+  else
+    {
+      NDArray result (a.dims ());
+
+      for (int i = 0; i < a.length (); i++)
+	{
+	  OCTAVE_QUIT;
+	  result(i) = pow (a(i), b);
+	}
+
+      retval = result;
+    }
+
+  return retval;
+}
+
+// -*- 4 -*-
+octave_value
+elem_xpow (const NDArray& a, const NDArray& b)
+{
+  octave_value retval;
+
+  dim_vector a_dims = a.dims ();
+  dim_vector b_dims = b.dims ();
+
+  if (a_dims != b_dims)
+    {
+      gripe_nonconformant ("operator .^", a_dims, b_dims);
+      return octave_value ();
+    }
+
+  int len = a.length ();
+
+  bool convert_to_complex = false;
+
+  for (int i = 0; i < len; i++)
+    {
+      OCTAVE_QUIT;
+      double atmp = a(i);
+      double btmp = b(i);
+      if (atmp < 0.0 && static_cast<int> (btmp) != btmp)
+	{
+	  convert_to_complex = true;
+	  goto done;
+	}
+    }
+
+done:
+
+  if (convert_to_complex)
+    {
+      ComplexNDArray complex_result (a_dims);
+
+      for (int i = 0; i < len; i++)
+	{
+	  OCTAVE_QUIT;
+	  Complex atmp (a(i));
+	  Complex btmp (b(i));
+	  complex_result(i) = pow (atmp, btmp);
+	}
+
+      retval = complex_result;
+    }
+  else
+    {
+      NDArray result (a_dims);
+
+      for (int i = 0; i < len; i++)
+	{
+	  OCTAVE_QUIT;
+	  result(i) = pow (a(i), b(i));
+	}
+
+      retval = result;
+    }
+
+  return retval;
+}
+
+// -*- 5 -*-
+octave_value
+elem_xpow (const NDArray& a, const Complex& b)
+{
+  ComplexNDArray result (a.dims ());
+
+  for (int i = 0; i < a.length (); i++)
+    {
+      OCTAVE_QUIT;
+      result(i) = pow (Complex (a(i)), b);
+    }
+
+  return result;
+}
+
+// -*- 6 -*-
+octave_value
+elem_xpow (const NDArray& a, const ComplexNDArray& b)
+{
+  dim_vector a_dims = a.dims ();
+  dim_vector b_dims = b.dims ();
+
+  if (a_dims != b_dims)
+    {
+      gripe_nonconformant ("operator .^", a_dims, b_dims);
+      return octave_value ();
+    }
+
+  ComplexNDArray result (a_dims);
+  for (int i = 0; i < a.length (); i++)
+    {
+      OCTAVE_QUIT;
+      result(i) = pow (Complex (a(i)), b(i));
+    }
+
+  return result;
+}
+
+// -*- 7 -*-
+octave_value
+elem_xpow (const Complex& a, const NDArray& b)
+{
+  ComplexNDArray result (b.dims ());
+  for (int i = 0; i < b.length (); i++)
+    {
+      OCTAVE_QUIT;
+      double btmp = b(i);
+      if (xisint (btmp))
+	result(i) = pow (a, static_cast<int> (btmp));
+      else
+	result(i) = pow (a, btmp);
+    }
+
+  return result;
+}
+
+// -*- 8 -*-
+octave_value
+elem_xpow (const Complex& a, const ComplexNDArray& b)
+{
+  ComplexNDArray result (b.dims ());
+  for (int i = 0; i < b.length (); i++)
+    {
+      OCTAVE_QUIT;
+      result(i) = pow (a, b(i));
+    }
+
+  return result;
+}
+
+// -*- 9 -*-
+octave_value
+elem_xpow (const ComplexNDArray& a, double b)
+{
+  ComplexNDArray result (a.dims ());
+
+  if (xisint (b))
+    {
+      for (int i = 0; i < a.length (); i++)
+	{
+	  OCTAVE_QUIT;
+	  result(i) = pow (a(i), static_cast<int> (b));
+	}
+    }
+  else
+    {
+      for (int i = 0; i < a.length (); i++)
+	{
+	  OCTAVE_QUIT;
+	  result(i) = pow (a(i), b);
+	}
+    }
+
+  return result;
+}
+
+// -*- 10 -*-
+octave_value
+elem_xpow (const ComplexNDArray& a, const NDArray& b)
+{
+  dim_vector a_dims = a.dims ();
+  dim_vector b_dims = b.dims ();
+
+  if (a_dims != b_dims)
+    {
+      gripe_nonconformant ("operator .^", a_dims, b_dims);
+      return octave_value ();
+    }
+
+  ComplexNDArray result (a_dims);
+  for (int i = 0; i < a.length (); i++)
+    {
+      OCTAVE_QUIT;
+      double btmp = b(i);
+      if (xisint (btmp))
+	result(i) = pow (a(i), static_cast<int> (btmp));
+      else
+	result(i) = pow (a(i), btmp);
+    }
+
+  return result;
+}
+
+// -*- 11 -*-
+octave_value
+elem_xpow (const ComplexNDArray& a, const Complex& b)
+{
+  ComplexNDArray result (a.dims ());
+  for (int i = 0; i < a.length (); i++)
+    {
+      OCTAVE_QUIT;
+      result(i) = pow (a(i), b);
+    }
+
+  return result;
+}
+
+// -*- 12 -*-
+octave_value
+elem_xpow (const ComplexNDArray& a, const ComplexNDArray& b)
+{
+  dim_vector a_dims = a.dims ();
+  dim_vector b_dims = b.dims ();
+
+  if (a_dims != b_dims)
+    {
+      gripe_nonconformant ("operator .^", a_dims, b_dims);
+      return octave_value ();
+    }
+
+  ComplexNDArray result (a_dims);
+  for (int i = 0; i < a.length (); i++)
+    {
+      OCTAVE_QUIT;
+      result(i) = pow (a(i), b(i));
+    }
 
   return result;
 }
